import { jsxs, jsx } from 'react/jsx-runtime';
import { forwardRef } from 'react';
import { c as cx } from './index-tZvMCc77.js';
import { I as Icon } from './Icon-BrdmZw1i-CG-LzgEz.js';
import { s as styles } from './Button.module-BqTaW8HK-BqTaW8HK.js';
import { S as Spinner } from './Spinner-DliJVzdW-BQlZEj4V.js';
import { u as useLayoutPropsUtil } from './useLayoutPropsUtil-GT5myWCm-Clw_nEze.js';

const ButtonLink = forwardRef(
  (props, ref) => {
    const { layoutStyles, componentProps } = useLayoutPropsUtil(props);
    const {
      children,
      className,
      appearance = "secondary",
      size = "medium",
      icon,
      loading = false,
      disabled,
      onClick,
      onKeyUp,
      onKeyDown,
      style,
      ...rest
    } = componentProps;
    const buttonClassNames = cx(className, styles["button"], {
      [styles["appearance-primary"]]: appearance === "primary",
      [styles["appearance-secondary"]]: appearance === "secondary",
      [styles["appearance-ghost"]]: appearance === "ghost",
      [styles["danger-secondary"]]: appearance === "danger-secondary",
      [styles["danger-primary"]]: appearance === "danger",
      [styles["size-small"]]: size === "small",
      [styles["size-medium"]]: size === "medium",
      [styles["size-large"]]: size === "large",
      [styles["type-icon"]]: !children,
      [styles["loading"]]: loading
    });
    const iconBefore = (icon2) => {
      if (icon2 && typeof icon2 === "object" && "before" in icon2) {
        return /* @__PURE__ */ jsx(
          Icon,
          {
            "aria-hidden": true,
            className: styles["icon"],
            inherit: true,
            svg: icon2.before
          }
        );
      }
      if (icon2 && typeof icon2 !== "object") {
        return /* @__PURE__ */ jsx(Icon, { "aria-hidden": true, className: styles["icon"], inherit: true, svg: icon2 });
      }
      return;
    };
    const handleOnClick = (e) => {
      if (disabled || loading) {
        e.preventDefault();
        return;
      }
      onClick?.(e);
    };
    const onKeyDownHandler = (e) => {
      if (e.code === "Space") {
        e.preventDefault();
        onKeyDown?.(e);
        return;
      }
      onKeyDown?.(e);
    };
    const onKeyUpHandler = (e) => {
      if (e.code === "Space" || e.code === "Enter") {
        e.preventDefault();
        onClick && e.currentTarget.click();
      }
      onKeyUp?.(e);
    };
    const styleCombined = {
      ...style,
      ...layoutStyles
    };
    return /* @__PURE__ */ jsxs(
      "a",
      {
        role: "link",
        className: buttonClassNames,
        "aria-disabled": disabled || loading,
        "aria-busy": loading,
        "data-anv": "button-link",
        tabIndex: disabled || loading ? -1 : 0,
        onClick: handleOnClick,
        onKeyDown: onKeyDownHandler,
        onKeyUp: onKeyUpHandler,
        style: styleCombined,
        ref,
        ...rest,
        children: [
          loading ? /* @__PURE__ */ jsx(Spinner, { inherit: true, className: styles["loading-spinner"] }) : icon ? iconBefore(icon) : null,
          children,
          typeof icon === "object" && "after" in icon ? /* @__PURE__ */ jsx(
            Icon,
            {
              className: styles["icon"],
              inherit: true,
              "aria-hidden": true,
              svg: icon.after
            }
          ) : null
        ]
      }
    );
  }
);
ButtonLink.displayName = "ButtonLink";

export { ButtonLink as B };
//# sourceMappingURL=ButtonLink-CSaxjhI2-KLVGwWjE.js.map
