import { jsxs, jsx } from 'react/jsx-runtime';
import { forwardRef, useState, useEffect, useId } from 'react';
import { c as cx } from './index-tZvMCc77.js';
import { I as Icon } from './Icon-BrdmZw1i-CG-LzgEz.js';
import { c as checkboxStyles, S as SvgIndeterminateCheckBox, a as SvgCheckBox, b as SvgCheckBoxOutlineBlank } from './Checkbox.module-DZ58p15b-BUsQC1lW.js';
import { L as Label, H as Helper } from './ProgressBar-CeClhdcf-Dcft7ZjO.js';
import { S as SrOnly } from './SrOnly-BsKDHetF-B93X65F1.js';
import { u as useLayoutPropsUtil } from './useLayoutPropsUtil-GT5myWCm-Clw_nEze.js';

const CheckboxGroup = forwardRef((props, ref) => {
  const { layoutStyles, componentProps } = useLayoutPropsUtil(props);
  const {
    className,
    children,
    legend,
    moreInfo,
    onBlur,
    onFocus,
    required,
    style,
    ...rest
  } = componentProps;
  const checkboxGroupClassNames = cx(checkboxStyles["checkbox-group"], className);
  const [openInfo, setOpenInfo] = useState(false);
  const styleCombined = {
    ...style,
    ...layoutStyles,
    alignItems: layoutStyles?.alignItems ?? (layoutStyles?.flexDirection === "row" ? "flex-start" : void 0)
  };
  const focusHandler = (e) => {
    onFocus?.(e);
    setOpenInfo(true);
  };
  const blurHandler = (e) => {
    onBlur?.(e);
    setOpenInfo(false);
  };
  const labelClassNames = cx(checkboxStyles["label"], {
    [checkboxStyles["direction-row"]]: layoutStyles?.flexDirection === "row"
  });
  return /* @__PURE__ */ jsxs(
    "fieldset",
    {
      role: "group",
      "data-anv": "checkbox-group",
      className: checkboxGroupClassNames,
      ref,
      style: styleCombined,
      onFocus: focusHandler,
      onBlur: blurHandler,
      ...rest,
      children: [
        /* @__PURE__ */ jsxs("legend", { className: checkboxStyles["legend"], children: [
          legend,
          required && ", required",
          moreInfo && /* @__PURE__ */ jsx(SrOnly, { children: moreInfo })
        ] }),
        /* @__PURE__ */ jsx(
          Label,
          {
            "aria-hidden": true,
            moreInfo,
            required,
            openMoreInfo: openInfo,
            className: labelClassNames,
            children: legend
          }
        ),
        /* @__PURE__ */ jsx(
          "div",
          {
            className: checkboxStyles["children"],
            style: {
              flexDirection: layoutStyles?.flexDirection,
              gap: layoutStyles?.gap
            },
            children
          }
        )
      ]
    }
  );
});
CheckboxGroup.displayName = "CheckboxGroup";

const CheckboxElement = forwardRef(
  (props, ref) => {
    const { layoutStyles, componentProps } = useLayoutPropsUtil(props);
    const {
      indeterminate,
      onChange,
      onClick,
      value,
      className,
      disabled,
      error,
      icons,
      checked: checkedProp,
      defaultChecked,
      label,
      style,
      required,
      description,
      hideCheckbox = false,
      ...rest
    } = componentProps;
    const {
      checked: checkedIcon = SvgCheckBox,
      indeterminate: indeterminateIcon = SvgIndeterminateCheckBox,
      unchecked: uncheckedIcon = SvgCheckBoxOutlineBlank
    } = { ...icons };
    const isControlled = typeof checkedProp !== "undefined";
    const [checked, setChecked] = useState(
      isControlled ? checkedProp : defaultChecked
    );
    useEffect(() => {
      if (!isControlled) return;
      setChecked(checkedProp);
    }, [checkedProp]);
    const onChangeHandler = (e) => {
      setChecked((prev) => {
        onChange?.(e, { value, checked: checkedProp ?? e.target.checked });
        if (!isControlled) return e.target.checked;
        return checkedProp;
      });
    };
    const onClickHandler = (e) => {
      onClick?.(e, {
        value,
        checked: checkedProp ?? e.target.checked
      });
    };
    const helperUid = useId();
    const wrapperClassNames = cx(
      checkboxStyles["wrapper"],
      { [checkboxStyles["focus"]]: hideCheckbox },
      className
    );
    const checkboxClassNames = cx(checkboxStyles["checkbox"], {
      [checkboxStyles["error"]]: error
    });
    const styleCombined = {
      ...style,
      ...layoutStyles
    };
    return /* @__PURE__ */ jsxs(
      "div",
      {
        className: wrapperClassNames,
        style: styleCombined,
        "data-anv": "checkbox",
        children: [
          /* @__PURE__ */ jsxs("label", { className: checkboxClassNames, children: [
            /* @__PURE__ */ jsx(
              "input",
              {
                type: "checkbox",
                disabled,
                value,
                onChange: onChangeHandler,
                onClick: onClickHandler,
                "aria-checked": indeterminate ? "mixed" : checked ?? defaultChecked,
                checked: isControlled ? checked : void 0,
                defaultChecked,
                "aria-invalid": error,
                "aria-describedby": helperUid,
                ref,
                ...rest
              }
            ),
            /* @__PURE__ */ jsxs(
              "span",
              {
                className: cx(checkboxStyles["icon-wrapper"], {
                  [checkboxStyles["sr-only"]]: hideCheckbox
                }),
                "aria-hidden": true,
                children: [
                  /* @__PURE__ */ jsx(
                    Icon,
                    {
                      size: "large",
                      svg: indeterminateIcon,
                      className: checkboxStyles["icon-indeterminate"]
                    }
                  ),
                  /* @__PURE__ */ jsx(
                    Icon,
                    {
                      size: "large",
                      svg: checkedIcon,
                      className: checkboxStyles["icon-checked"]
                    }
                  ),
                  /* @__PURE__ */ jsx(
                    Icon,
                    {
                      size: "large",
                      svg: uncheckedIcon,
                      className: checkboxStyles["icon-unchecked"]
                    }
                  )
                ]
              }
            ),
            /* @__PURE__ */ jsxs("span", { className: cx({ [checkboxStyles["focus-label"]]: hideCheckbox }), children: [
              label,
              required && /* @__PURE__ */ jsx("span", { "aria-hidden": true, className: checkboxStyles["required-asterisk"], children: "*" })
            ] })
          ] }),
          description ? /* @__PURE__ */ jsx("div", { className: checkboxStyles["helper-wrapper"], children: /* @__PURE__ */ jsx(Helper, { id: helperUid, description }) }) : null
        ]
      }
    );
  }
);
CheckboxElement.displayName = "Checkbox";
const Checkbox = Object.assign(CheckboxElement, {
  Group: CheckboxGroup
});

export { CheckboxGroup as C, Checkbox as a };
//# sourceMappingURL=Checkbox-CRurfeRE-BR_NXfh6.js.map
