import { jsxs, jsx } from 'react/jsx-runtime';
import { forwardRef, useContext } from 'react';
import { c as cx } from './index-tZvMCc77.js';
import { u as useAccessibleColor, t as tinycolor } from './useAccessibleColor-Dc6B_M-Z-BYKjkGRg.js';
import { S as SvgClose } from './close-DZj38AEh.js';
import { I as Icon } from './Icon-BrdmZw1i-CG-LzgEz.js';
import { u as useLayoutPropsUtil } from './useLayoutPropsUtil-GT5myWCm-Clw_nEze.js';
import { a as ThemeProviderContext } from './ThemeProvider-BIeaAmWx-DVYOQ6bw.js';
import { u as usePrefersColorScheme } from './usePrefersColorScheme-_hT7dK7_-_hT7dK7_.js';

import './Chip-DwiMFYBm.css';const chip = "_chip_9a6wr_2";
const inner = "_inner_9a6wr_15";
const close = "_close_9a6wr_28";
const styles = {
	chip: chip,
	inner: inner,
	close: close,
	"text-wrap": "_text-wrap_9a6wr_107",
	"size-small": "_size-small_9a6wr_122",
	"has-close": "_has-close_9a6wr_136"
};

const Chip = forwardRef((props, ref) => {
  const { layoutStyles, componentProps } = useLayoutPropsUtil(props);
  const {
    className,
    color,
    onClose,
    onClick,
    label,
    style,
    textWrap,
    size = "medium",
    tabIndex,
    ...rest
  } = componentProps;
  const removeText = ", removeable";
  const newLabel = `${label}${onClose ? removeText : ""}`;
  const ChipClassNames = cx(styles["chip"], className, {
    [styles["size-small"]]: size === "small",
    [styles["has-close"]]: !!onClose,
    [styles["text-wrap"]]: textWrap
  });
  const { mode: themeMode } = useContext(ThemeProviderContext);
  const { mode: sysMode } = usePrefersColorScheme();
  const mode = themeMode ?? sysMode;
  const { foreground, background, border } = useAccessibleColor(color, mode);
  const bgObj = tinycolor(background);
  const styleWithColor = {
    "--int-bg-color": color && background,
    "--int-font-color": color && foreground,
    "--int-border-color": color && border,
    "--int-close-background-color": color ? bgObj.isDark() ? bgObj.lighten(15).toHexString() : bgObj.darken(15).toHexString() : "#14141429",
    ...style,
    ...layoutStyles
  };
  const onKeyUpHandler = (e) => {
    switch (e.code) {
      case "Delete":
      case "Backspace":
        onClose?.(e);
        break;
      case "Enter":
        onClick?.(e);
        break;
    }
  };
  return /* @__PURE__ */ jsxs(
    "span",
    {
      className: ChipClassNames,
      style: styleWithColor,
      "data-anv": "chip",
      role: onClick ? "button" : void 0,
      ...onClick || onClose ? { ["aria-label"]: newLabel } : {},
      ...rest,
      ref,
      onClick,
      onKeyUp: onKeyUpHandler,
      tabIndex: onClick || onClose ? 0 : tabIndex,
      children: [
        /* @__PURE__ */ jsx("span", { className: styles.inner, children: label }),
        !!onClose && // this is disabled because this is fake button that only mouse users will interact
        // eslint-disable-next-line jsx-a11y/no-static-element-interactions, jsx-a11y/click-events-have-key-events
        /* @__PURE__ */ jsx(
          "span",
          {
            "aria-hidden": true,
            "aria-label": "remove button",
            className: styles["close"],
            onClick: (e) => {
              e.stopPropagation();
              onClose(e);
            },
            children: /* @__PURE__ */ jsx(Icon, { "aria-hidden": true, svg: SvgClose, size })
          }
        )
      ]
    }
  );
});
Chip.displayName = "Chip";

export { Chip as C };
//# sourceMappingURL=Chip-DwiMFYBm-CIDM1d8e.js.map
