import { jsxs, jsx } from 'react/jsx-runtime';
import { forwardRef, useId, useMemo } from 'react';
import { useTrackingId } from './useTrackingId.js';
import { c as childrenToString } from './childrenToString-Bz9MqbHb-Bz9MqbHb.js';
import { B as ButtonToggle } from './ButtonToggle-CvXIngRd-BiWpOOWr.js';
import { F as Flex } from './Flex-EX9xObMl-BPBQ7nb5.js';
import { L as Label, f as Tooltip, H as Helper } from './ProgressBar-CeClhdcf-Dcft7ZjO.js';

import './DaysOfTheWeek.css';const styles = {
	"days-of-the-week-container": "_days-of-the-week-container_13rkh_3",
	"days-of-the-week": "_days-of-the-week_13rkh_3",
	"button-toggle": "_button-toggle_13rkh_18",
	"button-toggle-wrapper": "_button-toggle-wrapper_13rkh_24"
};

const DAYS = [
  { short: "Mo", full: "Monday" },
  { short: "Tu", full: "Tuesday" },
  { short: "We", full: "Wednesday" },
  { short: "Th", full: "Thursday" },
  { short: "Fr", full: "Friday" },
  { short: "Sa", full: "Saturday" },
  { short: "Su", full: "Sunday" }
];
const DaysOfTheWeek$1 = forwardRef(
  (props, ref) => {
    const {
      selectedDays = [],
      onChange,
      disabled,
      firstDay = 7,
      hint,
      id: idProp,
      description,
      errorMessage,
      errorAriaLive,
      label,
      required,
      moreInfo,
      labelProps,
      ...rest
    } = props;
    const autoId = useId();
    const id = idProp ?? autoId;
    const labelUid = useId();
    const helperUid = useId();
    const orderedDays = useMemo(() => {
      const firstDayIndex = firstDay - 1;
      return [...DAYS.slice(firstDayIndex), ...DAYS.slice(0, firstDayIndex)];
    }, [firstDay]);
    const handleDayToggle = (index) => {
      const dayNumber = (index + firstDay - 1) % 7 + 1;
      const newSelectedDays = selectedDays.includes(dayNumber) ? selectedDays.filter((d) => d !== dayNumber) : [...selectedDays, dayNumber];
      onChange?.(newSelectedDays);
    };
    const isDayDisabled = (dayNumber) => {
      if (typeof disabled === "boolean") {
        return disabled;
      }
      if (Array.isArray(disabled)) {
        return disabled.includes(dayNumber);
      }
      return false;
    };
    return /* @__PURE__ */ jsxs("div", { className: styles["days-of-the-week-container"], children: [
      label ? /* @__PURE__ */ jsx(
        Label,
        {
          moreInfo,
          required,
          id: labelUid,
          htmlFor: id,
          ...labelProps,
          children: label
        }
      ) : null,
      /* @__PURE__ */ jsx(Flex, { ref, gap: 2, className: styles["days-of-the-week"], id, children: orderedDays.map((day, index) => {
        const dayNumber = (index + firstDay - 1) % 7 + 1;
        return /* @__PURE__ */ jsxs(Tooltip, { placement: "top", children: [
          /* @__PURE__ */ jsx(Tooltip.Trigger, { className: styles["button-toggle-wrapper"], children: /* @__PURE__ */ jsx(
            ButtonToggle,
            {
              checked: selectedDays.includes(dayNumber),
              onClick: () => handleDayToggle(index),
              disabled: isDayDisabled(dayNumber),
              className: styles["button-toggle"],
              id: label ? labelUid : void 0,
              "aria-describedby": helperUid,
              children: day.short
            }
          ) }),
          /* @__PURE__ */ jsx(Tooltip.Content, { children: day.full })
        ] }, day.short);
      }) }),
      /* @__PURE__ */ jsx(
        Helper,
        {
          id: helperUid,
          hint,
          description,
          errorMessage,
          errorAriaLive
        }
      )
    ] });
  }
);
DaysOfTheWeek$1.displayName = "DaysOfTheWeek";

const DaysOfTheWeek = forwardRef(
  (props, ref) => {
    const data = {
      description: childrenToString(props.description),
      hint: childrenToString(props.hint),
      label: childrenToString(props.label),
      labelProps: childrenToString(props.labelProps)
    };
    const trackingId = useTrackingId({
      name: "DaysOfTheWeek",
      data,
      hasOverride: !!props["data-tracking-id"]
    });
    return /* @__PURE__ */ jsx(DaysOfTheWeek$1, { ref, "data-tracking-id": trackingId, ...props });
  }
);
DaysOfTheWeek.displayName = "DaysOfTheWeek";

export { DaysOfTheWeek as D };
//# sourceMappingURL=DaysOfTheWeek-Dz-aZ-LW.js.map
