import { jsx, jsxs } from 'react/jsx-runtime';
import { forwardRef, useId, useState, useMemo, createContext, useContext } from 'react';
import { useTrackingId } from './useTrackingId.js';
import { c as childrenToString } from './childrenToString-Bz9MqbHb-Bz9MqbHb.js';
import { c as cx } from './index-tZvMCc77.js';
import { I as Icon } from './Icon-BrdmZw1i-CG-LzgEz.js';
import { S as SvgChevronRight } from './chevron_right-BdpsxX7x.js';
import { u as useLayoutPropsUtil } from './useLayoutPropsUtil-GT5myWCm-Clw_nEze.js';

import './Details.css';const details = "_details_1ozth_2";
const summary = "_summary_1ozth_15";
const arrow = "_arrow_1ozth_64";
const content = "_content_1ozth_28";
const expanded = "_expanded_1ozth_109";
const styles = {
	details: details,
	summary: summary,
	"content-wrapper": "_content-wrapper_1ozth_28",
	arrow: arrow,
	content: content,
	"is-expanded": "_is-expanded_1ozth_106",
	expanded: expanded
};

const DetailsArrow = forwardRef(
  function DetailsArrow2({ className: classNameProp, ...rest }, ref) {
    const { isExpanded } = useContext(DetailsContext);
    const className = cx(
      styles.arrow,
      { [styles["is-expanded"]]: isExpanded },
      classNameProp
    );
    return /* @__PURE__ */ jsx("span", { className, ref, ...rest, children: /* @__PURE__ */ jsx(Icon, { size: "large", svg: SvgChevronRight }) });
  }
);

const DetailsSummary$1 = forwardRef(function DetailsSummary2({ children, onClick: onClickProp, className: classNameProp, ...rest }, ref) {
  const { id, isExpanded, toggle } = useContext(DetailsContext);
  const handleClick = (...args) => {
    onClickProp?.(...args);
    toggle();
  };
  const className = cx(styles.summary, classNameProp);
  return /* @__PURE__ */ jsxs(
    "button",
    {
      "data-anv": "details-summary",
      "aria-controls": id,
      "aria-expanded": isExpanded,
      className,
      onClick: handleClick,
      ref,
      ...rest,
      children: [
        /* @__PURE__ */ jsx(DetailsArrow, {}),
        children
      ]
    }
  );
});

const DetailsContent$1 = forwardRef(
  function DetailsContent2({
    className: classNameProp,
    children,
    height,
    maxHeight,
    style: styleProp,
    ...rest
  }, ref) {
    const { id, isExpanded } = useContext(DetailsContext);
    const style = {
      height,
      maxHeight,
      ...height || maxHeight ? { overflow: "auto" } : {},
      ...styleProp
    };
    return /* @__PURE__ */ jsx(
      "div",
      {
        "data-anv": "details-content",
        id,
        className: cx(styles["content-wrapper"], {
          [styles.expanded]: isExpanded
        }),
        ref,
        children: /* @__PURE__ */ jsx("div", { className: styles.content, children: /* @__PURE__ */ jsx("div", { className: classNameProp, style, ...rest, children }) })
      }
    );
  }
);

const DetailsContext = createContext({
  id: "",
  isExpanded: false,
  expanded: () => void 0,
  close: () => void 0,
  toggle: () => void 0
});
const DetailsElement$1 = forwardRef(
  function Details2(props, ref) {
    const { layoutStyles, componentProps } = useLayoutPropsUtil(props);
    const {
      children,
      id: idProp,
      expanded: expandedControlled,
      defaultExpanded = false,
      style,
      className,
      ...rest
    } = componentProps;
    const id = useId();
    const [isExpanded, setIsOpen] = useState(defaultExpanded);
    function expanded() {
      setIsOpen(true);
    }
    function close() {
      setIsOpen(false);
    }
    function toggle() {
      setIsOpen((prevIsOpen) => !prevIsOpen);
    }
    const styleCombined = {
      ...style,
      ...layoutStyles
    };
    const value = useMemo(
      () => ({
        id: idProp != null ? idProp : id,
        isExpanded: expandedControlled != null ? expandedControlled : isExpanded,
        expanded,
        close,
        toggle
      }),
      [id, idProp, isExpanded, expandedControlled]
    );
    return /* @__PURE__ */ jsx(DetailsContext.Provider, { value, children: /* @__PURE__ */ jsx(
      "div",
      {
        "data-anv": "details",
        ref,
        className: cx(styles.details, className),
        style: styleCombined,
        ...rest,
        children
      }
    ) });
  }
);
const Details$1 = Object.assign(DetailsElement$1, {
  Summary: DetailsSummary$1,
  Content: DetailsContent$1,
  Arrow: DetailsArrow
});

const DetailsElement = forwardRef(
  (props, ref) => {
    return /* @__PURE__ */ jsx(Details$1, { ref, ...props });
  }
);
const DetailsSummary = forwardRef(
  (props, ref) => {
    const data = {
      children: childrenToString(props.children)
    };
    const trackingId = useTrackingId({
      name: "DetailsSummary",
      data,
      hasOverride: !!props["data-tracking-id"]
    });
    return /* @__PURE__ */ jsx(Details$1.Summary, { ref, "data-tracking-id": trackingId, ...props });
  }
);
const DetailsContent = forwardRef(
  (props, ref) => {
    return /* @__PURE__ */ jsx(Details$1.Content, { ref, ...props });
  }
);
const Details = Object.assign(DetailsElement, {
  Summary: DetailsSummary,
  Content: DetailsContent
});

export { Details as D, DetailsSummary as a, DetailsContent as b };
//# sourceMappingURL=Details-ChZdA5Yo.js.map
