import { jsxs, jsx } from 'react/jsx-runtime';
import { forwardRef, useContext, useRef, useState, useId, useCallback, useEffect } from 'react';
import { useTrackingId } from './useTrackingId.js';
import { c as childrenToString } from './childrenToString-Bz9MqbHb-Bz9MqbHb.js';
import { c as cx } from './index-tZvMCc77.js';
import { i as DialogContext, u as useDialogTransitionStates, j as useKeyboardFocusables, k as useDialogScrollLock, g as getActiveElement, l as ToastProvider, m as ToasterPopover, n as ToasterContent } from './ProgressBar-CeClhdcf-Dcft7ZjO.js';
import { S as SvgClose } from './close-DZj38AEh.js';
import { T as Text } from './Text-CN_-FF7J-Dzoy8A70.js';
import { B as Button } from './Button-C-QpfgfF-CRBE7KiD.js';
import { u as useMergeRefs } from './useMergeRefs-Bde85AWI-Bde85AWI.js';

import './Dialog.css';const dialog = "_dialog_17u1d_2";
const container = "_container_17u1d_20";
const content = "_content_17u1d_33";
const header = "_header_17u1d_40";
const footer = "_footer_17u1d_60";
const closing = "_closing_17u1d_76";
const large = "_large_17u1d_82";
const fullscreen = "_fullscreen_17u1d_82";
const sticky = "_sticky_17u1d_102";
const styles = {
	dialog: dialog,
	container: container,
	content: content,
	header: header,
	"close-container": "_close-container_17u1d_53",
	footer: footer,
	closing: closing,
	large: large,
	fullscreen: fullscreen,
	sticky: sticky,
	"close-button": "_close-button_17u1d_108"
};

function useDialogContext() {
  const context = useContext(DialogContext);
  if (!context) {
    throw new Error(
      "useDialogContext must be used within a DialogContextProvider"
    );
  }
  return context;
}

const DialogCancelButton$1 = forwardRef((props, ref) => {
  const { onClick, ...rest } = props;
  const { close } = useDialogContext();
  const onClickHandler = (e) => {
    onClick?.(e);
    close();
  };
  return /* @__PURE__ */ jsx(
    Button,
    {
      "aria-label": "Close dialog",
      "data-anv": "dialog-cancel-button",
      onClick: onClickHandler,
      ref,
      ...rest
    }
  );
});
DialogCancelButton$1.displayName = "DialogCancelButton";

const DialogHeader$1 = forwardRef(
  (props, ref) => {
    const { children, className, ...rest } = props;
    const headerClassNames = cx(className, styles["header"]);
    return /* @__PURE__ */ jsxs(
      "header",
      {
        className: headerClassNames,
        "data-anv": "dialog-header",
        ref,
        ...rest,
        children: [
          /* @__PURE__ */ jsx(Text, { variant: "headline", el: "h1", children }),
          /* @__PURE__ */ jsx("span", { className: styles["close-container"], children: /* @__PURE__ */ jsx(
            DialogCancelButton$1,
            {
              className: styles["close-button"],
              size: "small",
              appearance: "ghost",
              "aria-label": "Close dialog",
              icon: SvgClose
            }
          ) })
        ]
      }
    );
  }
);
DialogHeader$1.displayName = "DialogHeader";

const DialogFooter$1 = forwardRef(
  (props, ref) => {
    const { children, className, sticky = false, ...rest } = props;
    const footerClassNames = cx(styles["footer"], className, {
      [styles["sticky"]]: sticky
    });
    return /* @__PURE__ */ jsx(
      "footer",
      {
        className: footerClassNames,
        "data-anv": "dialog-footer",
        ref,
        ...rest,
        children
      }
    );
  }
);
DialogFooter$1.displayName = "DialogFooter";

const DialogContent$1 = forwardRef(
  (props, ref) => {
    const { children, className, ...rest } = props;
    const contentClassNames = cx(styles["content"], className);
    return /* @__PURE__ */ jsx(
      "div",
      {
        className: contentClassNames,
        "data-anv": "dialog-content",
        ref,
        ...rest,
        children
      }
    );
  }
);
DialogContent$1.displayName = "DialogContent";

const DialogElement$1 = forwardRef(
  (props, ref) => {
    const {
      className,
      open = false,
      children,
      onOpen,
      onOpenChange,
      onClose,
      onKeyDown,
      fullScreen = false,
      disableCloseOnEscape = false,
      disableCloseOnClickOutside = false,
      size,
      enableScrollChaining,
      onOpenAnimationStart,
      onOpenAnimationComplete,
      onCloseAnimationStart,
      onCloseAnimationComplete,
      ...rest
    } = props;
    const elRef = useRef(null);
    const contentRef = useRef(null);
    const [hasOpenPopover, setHasOpenPopover] = useState(false);
    const id = useId();
    const { state, isOpenOrOpening, beginClosing } = useDialogTransitionStates(
      elRef,
      open,
      {
        onOpenAnimationStart: useCallback(() => {
          onOpenAnimationStart?.();
        }, [onOpenAnimationStart]),
        onOpenAnimationComplete: useCallback(() => {
          onOpenAnimationComplete?.();
          onOpen?.();
        }, [onOpen, onOpenAnimationComplete]),
        onCloseAnimationStart: useCallback(() => {
          onCloseAnimationStart?.();
        }, [onCloseAnimationStart]),
        onCloseAnimationComplete: useCallback(() => {
          onCloseAnimationComplete?.();
          onClose?.();
        }, [onClose, onCloseAnimationComplete])
      }
    );
    const initial = useRef(true);
    useEffect(() => {
      if (initial.current) {
        initial.current = false;
      } else {
        onOpenChange?.(isOpenOrOpening);
      }
    }, [id, onOpenChange, isOpenOrOpening]);
    const classNames = cx([styles["dialog"]], className, {
      [styles["closing"]]: state === "closing",
      [styles["fullscreen"]]: fullScreen,
      [styles["large"]]: size === "large"
    });
    const { focusables } = useKeyboardFocusables(contentRef, {
      observeChange: true
    });
    useDialogScrollLock({
      open: isOpenOrOpening,
      id,
      enableScrollChaining,
      elementRef: elRef
    });
    useEffect(() => {
      if (typeof document === "undefined" || disableCloseOnClickOutside) return;
      const onClickOutsideHandler = (e) => {
        if (hasOpenPopover) return;
        if (e.composedPath()[0] === elRef.current) {
          beginClosing();
        }
      };
      document.addEventListener("mousedown", onClickOutsideHandler);
      return () => document.removeEventListener("mousedown", onClickOutsideHandler);
    }, [disableCloseOnClickOutside, beginClosing, hasOpenPopover]);
    useEffect(() => {
      if (!isOpenOrOpening) return;
      if (!focusables) return;
      const activeElement = getActiveElement(document);
      if (!activeElement) return;
      if (activeElement.dataset.anv !== "dialog-header-close-button" && focusables.includes(activeElement)) {
        return;
      }
      if (focusables[0]?.dataset.anv === "dialog-header-close-button" && focusables[1]) {
        focusables[1].focus();
      } else {
        focusables[0]?.focus();
      }
    }, [isOpenOrOpening, focusables]);
    const onKeyDownHandler = (e) => {
      onKeyDown?.(e);
      if (e.code === "Escape") {
        e.preventDefault();
        if (disableCloseOnEscape) return;
        if (hasOpenPopover) return;
        beginClosing();
        return;
      }
      if (e.code === "Tab") {
        if (e.shiftKey && e.target === focusables?.[0]) {
          e.preventDefault();
          focusables[focusables.length - 1]?.focus();
          return;
        }
        if (e.target === focusables?.[focusables.length - 1] && !e.shiftKey) {
          e.preventDefault();
          focusables[0].focus();
          return;
        }
      }
    };
    return (
      // dialog element does seem to be interactive on MDN guideline
      // eslint-disable-next-line jsx-a11y/no-noninteractive-element-interactions
      /* @__PURE__ */ jsxs(
        "dialog",
        {
          className: classNames,
          "data-anv": "dialog",
          "data-anv-scroll-chaining": enableScrollChaining,
          "data-anv-transition-state": state,
          ref: useMergeRefs([ref, elRef]),
          onKeyDown: onKeyDownHandler,
          ...rest,
          children: [
            /* @__PURE__ */ jsx(ToastProvider, { isDialogToaster: open, children: /* @__PURE__ */ jsx(ToasterPopover, { children: /* @__PURE__ */ jsx(ToasterContent, { id: "dialog-toaster" }) }) }),
            /* @__PURE__ */ jsx(
              DialogContext.Provider,
              {
                value: {
                  close: beginClosing,
                  ref: elRef,
                  hasOpenPopover,
                  setHasOpenPopover
                },
                children: /* @__PURE__ */ jsx(
                  "section",
                  {
                    ref: contentRef,
                    className: styles["container"],
                    "data-open": open,
                    children
                  }
                )
              }
            )
          ]
        }
      )
    );
  }
);
DialogElement$1.displayName = "Dialog";
const Dialog$1 = Object.assign(DialogElement$1, {
  Header: DialogHeader$1,
  Footer: DialogFooter$1,
  Content: DialogContent$1,
  CancelButton: DialogCancelButton$1
});

const DialogElement = forwardRef(
  (props, ref) => {
    return /* @__PURE__ */ jsx(Dialog$1, { ref, ...props });
  }
);
const DialogHeader = forwardRef(
  (props, ref) => {
    const data = {
      children: childrenToString(props.children)
    };
    const trackingId = useTrackingId({
      name: "Dialog",
      data,
      hasOverride: !!props["data-tracking-id"]
    });
    return /* @__PURE__ */ jsx(DialogHeader$1, { ref, "data-tracking-id": trackingId, ...props });
  }
);
const DialogFooter = forwardRef(
  (props, ref) => {
    return /* @__PURE__ */ jsx(DialogFooter$1, { ref, ...props });
  }
);
const DialogContent = forwardRef(
  (props, ref) => {
    return /* @__PURE__ */ jsx(DialogContent$1, { ref, ...props });
  }
);
const DialogCancelButton = forwardRef(
  (props, ref) => {
    const data = {
      title: props.title,
      appearance: props.appearance,
      size: props.size,
      type: props.type
    };
    const trackingId = useTrackingId({
      name: "DialogCancelButton",
      data,
      hasOverride: !!props["data-tracking-id"]
    });
    return /* @__PURE__ */ jsx(
      DialogCancelButton$1,
      {
        ref,
        "data-tracking-id": trackingId,
        ...props
      }
    );
  }
);
const Dialog = Object.assign(DialogElement, {
  Header: DialogHeader,
  Footer: DialogFooter,
  Content: DialogContent,
  CancelButton: DialogCancelButton
});

export { Dialog as D, DialogHeader as a, DialogFooter as b, DialogContent as c, DialogCancelButton as d };
//# sourceMappingURL=Dialog-DJhN8QWP.js.map
