import { jsxs, jsx } from 'react/jsx-runtime';
import { forwardRef, useRef, useId, useState, useEffect, useContext, createContext } from 'react';
import { useTrackingId } from './useTrackingId.js';
import { c as cx } from './index-tZvMCc77.js';
import { s as styles } from './ListView.module-MVsNF0X0-MVsNF0X0.js';
import { g as getActiveElement } from './ProgressBar-CeClhdcf-Dcft7ZjO.js';
import { u as useLayoutPropsUtil } from './useLayoutPropsUtil-GT5myWCm-Clw_nEze.js';
import { u as useMergeRefs } from './useMergeRefs-Bde85AWI-Bde85AWI.js';
import { a as Checkbox } from './Checkbox-CRurfeRE-BR_NXfh6.js';

function mapOrder(array, order, key) {
  array.sort(function(a, b) {
    const A = a[key], B = b[key];
    if (order.indexOf(A) > order.indexOf(B)) {
      return 1;
    } else {
      return -1;
    }
  });
  return array;
}

const listViewKeyboardNavigation = (e, options, focusedItem, setFocusedItem, parent, currentFocusId) => {
  if (!options) return;
  let activeElement;
  switch (e.code) {
    case "Enter":
    case "Space":
      options[focusedItem.row].focusables[focusedItem.col].click();
      activeElement = getActiveElement(document);
      if (!activeElement) break;
      activeElement.click();
      e.preventDefault();
      break;
    case "ArrowDown":
      parent?.focus();
      options[focusedItem.row].focusables[focusedItem.col].removeAttribute(
        "data-interactive"
      );
      if (focusedItem.row === options.length - 1) {
        options[0].focusables[focusedItem.col].setAttribute(
          "data-interactive",
          "focus-visible"
        );
        currentFocusId(options[0].focusables[focusedItem.col].id);
        setFocusedItem((prev) => {
          return { ...prev, row: 0 };
        });
        break;
      }
      options[focusedItem.row + 1].focusables[focusedItem.col].setAttribute(
        "data-interactive",
        "focus-visible"
      );
      currentFocusId(
        options[focusedItem.row + 1].focusables[focusedItem.col].id
      );
      setFocusedItem((prev) => {
        return { ...prev, row: focusedItem.row + 1 };
      });
      break;
    case "ArrowUp":
      parent?.focus();
      options[focusedItem.row].focusables[focusedItem.col].removeAttribute(
        "data-interactive"
      );
      if (focusedItem.row === 0) {
        options[options.length - 1].focusables[focusedItem.col].setAttribute(
          "data-interactive",
          "focus-visible"
        );
        currentFocusId(
          options[options.length - 1].focusables[focusedItem.col].id
        );
        setFocusedItem((prev) => {
          return { ...prev, row: options.length - 1 };
        });
        break;
      }
      options[focusedItem.row - 1].focusables[focusedItem.col].setAttribute(
        "data-interactive",
        "focus-visible"
      );
      currentFocusId(
        options[focusedItem.row - 1].focusables[focusedItem.col].id
      );
      setFocusedItem((prev) => {
        return { ...prev, row: focusedItem.row - 1 };
      });
      break;
    case "ArrowRight":
      parent?.focus();
      options[focusedItem.row].focusables[focusedItem.col].removeAttribute(
        "data-interactive"
      );
      if (focusedItem.col === options[focusedItem.row].focusables.length - 1) {
        options[focusedItem.row].focusables[0].setAttribute(
          "data-interactive",
          "focus-visible"
        );
        currentFocusId(options[focusedItem.row].focusables[0].id);
        setFocusedItem((prev) => {
          return {
            ...prev,
            col: 0
          };
        });
        break;
      }
      options[focusedItem.row].focusables[focusedItem.col + 1].setAttribute(
        "data-interactive",
        "focus-visible"
      );
      currentFocusId(
        options[focusedItem.row].focusables[focusedItem.col + 1].id
      );
      setFocusedItem((prev) => {
        return { ...prev, col: focusedItem.col + 1 };
      });
      break;
    case "ArrowLeft":
      parent?.focus();
      options[focusedItem.row].focusables[focusedItem.col].removeAttribute(
        "data-interactive"
      );
      if (focusedItem.col === 0) {
        options[focusedItem.row].focusables[options[focusedItem.row].focusables.length - 1].setAttribute("data-interactive", "focus-visible");
        currentFocusId(
          options[focusedItem.row].focusables[options[focusedItem.row].focusables.length - 1].id
        );
        setFocusedItem((prev) => {
          return {
            ...prev,
            col: options[focusedItem.row].focusables.length - 1
          };
        });
        break;
      }
      options[focusedItem.row].focusables[focusedItem.col - 1].setAttribute(
        "data-interactive",
        "focus-visible"
      );
      currentFocusId(
        options[focusedItem.row].focusables[focusedItem.col - 1].id
      );
      setFocusedItem((prev) => {
        return { ...prev, col: focusedItem.col - 1 };
      });
      break;
  }
};

const ListViewOption$1 = forwardRef(
  (props, ref) => {
    const {
      className,
      children,
      onClick,
      onKeyDown,
      onKeyUp,
      onBlur,
      onChange,
      style,
      disabled: disabledProp,
      id,
      ...remainingProps
    } = props;
    const optionRef = useRef(null);
    const mergedRef = useMergeRefs([ref, optionRef]);
    const itemRef = useRef();
    const cellRef = useRef(null);
    const rowId = useId();
    const [isSelected, setIsSelected] = useState(false);
    const { selectedItems, setSelectedItems, controlled } = useListView();
    const disabled = "item" in remainingProps ? disabledProp || remainingProps.item.disabled : disabledProp;
    useEffect(() => {
      const focusables = optionRef.current?.querySelectorAll(
        "button:not(:disabled):not([aria-disabled='true']), input:not(:disabled):not([aria-disabled='true']), [tabindex='0']:not(:disabled):not([aria-disabled='true'])"
      );
      focusables?.forEach((item, i) => {
        item.setAttribute("tabindex", "-1");
        if (item.hasAttribute("id")) return;
        item.setAttribute("id", `${rowId}-${i}`);
      });
    }, [rowId]);
    useEffect(() => {
      if ("item" in remainingProps) {
        const isPartOfSelectedItems = selectedItems.some((item) => {
          return item.label === remainingProps.item.label;
        });
        setIsSelected(isPartOfSelectedItems);
      } else {
        const isPartOfSelectedItems = selectedItems.includes(
          remainingProps.label
        );
        setIsSelected(isPartOfSelectedItems);
      }
    }, [controlled, remainingProps, selectedItems]);
    const onChangeHandler = (e) => {
      onChange?.(e, { checked: isSelected });
    };
    const onClickHandler = () => {
      if (controlled) return;
      updateSelectedItems();
    };
    function updateSelectedItems() {
      if ("item" in remainingProps) {
        const isPartOfSelectedItems = selectedItems.some((item) => {
          return item.label === remainingProps.item.label;
        });
        if (isPartOfSelectedItems) {
          setSelectedItems(
            (prev) => prev.filter(
              (item) => item?.label !== remainingProps.item.label
            )
          );
          setIsSelected(false);
        } else {
          setSelectedItems((prev) => [...prev, remainingProps.item]);
          setIsSelected(true);
        }
      } else {
        const isPartOfSelectedItems = selectedItems.some((item) => {
          return item === remainingProps.label;
        });
        if (isPartOfSelectedItems) {
          setSelectedItems(
            (prev) => prev.filter((item) => item !== remainingProps.label)
          );
          setIsSelected(false);
        } else {
          setSelectedItems((prev) => [...prev, remainingProps.label]);
          setIsSelected(true);
        }
      }
    }
    if ("item" in remainingProps) {
      itemRef.current = remainingProps.item;
      const { item, ...rest } = remainingProps;
      return /* @__PURE__ */ jsxs(
        "div",
        {
          className: cx([styles["listview-option"]], className),
          "data-anv": "listview-option",
          style,
          ref: mergedRef,
          "aria-disabled": disabled,
          "aria-selected": isSelected,
          "aria-label": item.label,
          role: "row",
          ...rest,
          children: [
            /* @__PURE__ */ jsx("div", { className: styles["cell"], ref: cellRef, role: "gridcell", children: /* @__PURE__ */ jsx(
              Checkbox,
              {
                disabled,
                checked: isSelected,
                "aria-label": item.label,
                onChange: onChangeHandler,
                onClick: onClickHandler
              }
            ) }),
            children
          ]
        }
      );
    }
    return /* @__PURE__ */ jsxs(
      "div",
      {
        className: cx([styles["listview-option"]], className),
        "data-anv": "listview-option",
        style,
        ref: mergedRef,
        "aria-disabled": disabled,
        "aria-selected": isSelected,
        "aria-label": "label" in props ? props.label : "Select",
        role: "row",
        ...remainingProps,
        children: [
          /* @__PURE__ */ jsx("div", { className: styles["cell"], ref: cellRef, role: "gridcell", children: /* @__PURE__ */ jsx(
            Checkbox,
            {
              disabled,
              checked: isSelected,
              "aria-label": "label" in props ? props.label : "Select",
              onChange: onChangeHandler,
              onClick: onClickHandler
            }
          ) }),
          children
        ]
      }
    );
  }
);
ListViewOption$1.displayName = "ListViewOption";

const ListViewOptionCell$1 = forwardRef((props, ref) => {
  const { ...rest } = props;
  return /* @__PURE__ */ jsx("div", { role: "gridcell", "data-anv": "listview-option-cell", ...rest, ref });
});
ListViewOptionCell$1.displayName = "ListViewOptionCell";

const ListViewContext = createContext(null);
const getFocusables = (el) => {
  return el.querySelectorAll(
    "button:not(:disabled):not([aria-disabled='true']), input:not(:disabled):not([aria-disabled='true']), [tabindex='0']:not(:disabled):not([aria-disabled='true'])"
  );
};
const ListViewElement$1 = function(props, ref) {
  const { layoutStyles, componentProps } = useLayoutPropsUtil(props);
  const {
    onSelectionChange,
    className,
    selected,
    defaultSelected,
    style,
    onKeyDown,
    ...remainingProps
  } = componentProps;
  const ListViewRef = useRef(null);
  const isFocusVisible = useRef(true);
  const combinedRef = useMergeRefs([ref, ListViewRef]);
  const [options, setOptions] = useState();
  const [currentActive, setCurrentActive] = useState();
  const [selectedItems, setSelectedItems] = useState(
    selected ?? defaultSelected ?? []
  );
  const [focusedItem, setFocusedItem] = useState({
    row: 0,
    col: 0
  });
  const styleCombined = {
    ...style,
    ...layoutStyles
  };
  const onFocusHandler = (e) => {
    if (!isFocusVisible.current) return;
    if (!options) return;
    options[focusedItem.row].focusables[focusedItem.col].setAttribute(
      "data-interactive",
      "focus-visible"
    );
    return;
  };
  const onBlurHandler = () => {
    if (!options) return;
    options[focusedItem.row].focusables[focusedItem.col]?.removeAttribute(
      "data-interactive"
    );
    return;
  };
  const onKeyDownHandler = (e) => {
    onKeyDown?.(e);
    if (!options) return;
    isFocusVisible.current = true;
    listViewKeyboardNavigation(
      e,
      options,
      focusedItem,
      setFocusedItem,
      ListViewRef.current,
      (id) => setCurrentActive(id)
    );
  };
  const onMouseDownHandler = (e) => {
    isFocusVisible.current = false;
    if (options && ListViewRef.current) {
      options[focusedItem.row].focusables[focusedItem.col]?.removeAttribute(
        "data-interactive"
      );
      const closestFocusable = e.target.closest(
        "button:not(:disabled):not([aria-disabled='true']), input:not(:disabled):not([aria-disabled='true']), [data-anv='checkbox']"
      );
      const optionRow = e.target.closest(
        '[data-anv="listview-option"]'
      );
      if (!optionRow || optionRow.ariaDisabled) return;
      const row = options.findIndex((option) => option.node === optionRow);
      if (!closestFocusable) {
        options[row].focusables[0].click();
        return;
      }
      const col = Array.prototype.indexOf.call(
        options[row].focusables,
        closestFocusable?.getAttribute("data-anv") === "checkbox" ? closestFocusable.children[0] : closestFocusable
      );
      setFocusedItem({ row, col });
    }
  };
  useEffect(() => {
    if (!ListViewRef.current) return;
    const optionArr = ListViewRef.current.querySelectorAll(
      "div[data-anv='listview-option']:not([aria-disabled='true'])"
    );
    const makeTree = Array.from(optionArr).map((option) => {
      const childFocusables = getFocusables(option);
      return {
        node: option,
        focusables: childFocusables
      };
    });
    setOptions(makeTree);
  }, [props.children]);
  const prevSelectedItems = useRef();
  useEffect(() => {
    if (!options) return;
    const compareArr = options.map((option) => option.node.ariaLabel);
    const orderedSelectedItems = mapOrder(selectedItems, compareArr, "label");
    if (JSON.stringify(prevSelectedItems.current) === JSON.stringify(orderedSelectedItems))
      return;
    onSelectionChange?.(orderedSelectedItems);
    prevSelectedItems.current = orderedSelectedItems;
  }, [onSelectionChange, options, selectedItems]);
  useEffect(() => {
    if (!selected) return;
    const filterDuplicates = selected.reduce(
      (acc, current) => {
        const isDup = acc.find((item) => item.label === current.label);
        if (!isDup) {
          return acc.concat([current]);
        } else {
          return acc;
        }
      },
      []
    );
    if (!options) return;
    const compareArr = options.map((option) => option.node.ariaLabel);
    const orderedSelected = mapOrder(filterDuplicates, compareArr, "label");
    if (JSON.stringify(prevSelectedItems.current) === JSON.stringify(orderedSelected))
      return;
    onSelectionChange?.(orderedSelected);
    setSelectedItems(orderedSelected);
    prevSelectedItems.current = orderedSelected;
  }, [onSelectionChange, options, selected]);
  const ListViewClassNames = cx([styles["listview"]], className);
  if ("items" in remainingProps) {
    const { children: children2, items, ...rest2 } = remainingProps;
    return /* @__PURE__ */ jsx(
      ListViewContext.Provider,
      {
        value: {
          options,
          onSelectionChange,
          selectedItems,
          setSelectedItems,
          items,
          controlled: !!selected
        },
        children: /* @__PURE__ */ jsx(
          "div",
          {
            ref: combinedRef,
            className: ListViewClassNames,
            style: styleCombined,
            "data-anv": "listview",
            role: "grid",
            "aria-multiselectable": "true",
            onFocus: onFocusHandler,
            onBlur: onBlurHandler,
            onKeyDown: onKeyDownHandler,
            onMouseDown: onMouseDownHandler,
            "aria-activedescendant": currentActive,
            tabIndex: 0,
            ...rest2,
            children: children2?.({
              items: items.map((item) => {
                return item;
              })
            })
          }
        )
      }
    );
  }
  const { children, ...rest } = remainingProps;
  return /* @__PURE__ */ jsx(
    ListViewContext.Provider,
    {
      value: {
        options,
        onSelectionChange,
        selectedItems,
        setSelectedItems,
        controlled: !!selected
      },
      children: /* @__PURE__ */ jsx(
        "div",
        {
          ref: combinedRef,
          className: ListViewClassNames,
          style: styleCombined,
          "data-anv": "listview",
          role: "grid",
          onFocus: onFocusHandler,
          onBlur: onBlurHandler,
          onKeyDown: onKeyDownHandler,
          onMouseDown: onMouseDownHandler,
          "aria-activedescendant": currentActive,
          tabIndex: 0,
          ...rest,
          children
        }
      )
    }
  );
};
function useListView() {
  const context = useContext(ListViewContext);
  if (context == null) {
    throw new Error("useListView must be wrapped in <ListView />");
  }
  return context;
}
ListViewElement$1.displayName = "ListView";
const ListView$1 = Object.assign(
  forwardRef(ListViewElement$1),
  {
    Option: ListViewOption$1,
    OptionCell: ListViewOptionCell$1
  }
);

const ListViewElement = function(props, ref) {
  return /* @__PURE__ */ jsx(ListView$1, { ref, ...props });
};
const ListViewOption = forwardRef(
  (props, ref) => {
    const data = {
      label: "item" in props ? props.item?.label : props.label
    };
    const trackingId = useTrackingId({
      name: "ListViewOption",
      data,
      hasOverride: !!props["data-tracking-id"]
    });
    return /* @__PURE__ */ jsx(ListViewOption$1, { ref, "data-tracking-id": trackingId, ...props });
  }
);
const ListViewOptionCell = forwardRef(
  (props, ref) => {
    return /* @__PURE__ */ jsx(ListViewOptionCell$1, { ref, ...props });
  }
);
const ListView = Object.assign(
  forwardRef(ListViewElement),
  {
    Option: ListViewOption,
    OptionCell: ListViewOptionCell
  }
);

export { ListView as L, ListViewOption as a, ListViewOptionCell as b };
//# sourceMappingURL=ListView-zlg5FlKW.js.map
