import { jsxs, jsx } from 'react/jsx-runtime';
import { forwardRef, useState, useRef, useEffect, useCallback } from 'react';
import { c as cx } from './index-tZvMCc77.js';
import { u as useLayoutPropsUtil } from './useLayoutPropsUtil-GT5myWCm-Clw_nEze.js';
import { g as getKeyboardFocusableElements } from './getKeyboardFocusableElements-QqcABz0D.js';
import { F as Flex } from './Flex-EX9xObMl-BPBQ7nb5.js';

import './Overflow-ENfRRD_5.css';const overflow = "_overflow_1oh8a_1";
const expanded = "_expanded_1oh8a_1";
const content = "_content_1oh8a_57";
const horizontal = "_horizontal_1oh8a_104";
const truncate = "_truncate_1oh8a_107";
const styles = {
	overflow: overflow,
	expanded: expanded,
	"shadow-top": "_shadow-top_1oh8a_1",
	"shadow-right": "_shadow-right_1oh8a_5",
	"shadow-bottom": "_shadow-bottom_1oh8a_9",
	"shadow-left": "_shadow-left_1oh8a_13",
	"overflow-text": "_overflow-text_1oh8a_19",
	"expand-button": "_expand-button_1oh8a_32",
	content: content,
	horizontal: horizontal,
	truncate: truncate
};

const OverflowText = forwardRef(
  (props, ref) => {
    const { rows = 1, ...otherProps } = props;
    const { layoutStyles, componentProps } = useLayoutPropsUtil(otherProps);
    const [expanded, setExpanded] = useState(false);
    const [heights, setHeights] = useState({ clientHeight: 0, scrollHeight: 0 });
    const { className, style, children, ...rest } = componentProps;
    const contentRef = useRef(null);
    const styledCombined = {
      ...style,
      ...layoutStyles,
      "--overflow-text-row": expanded || rows === "unlimited" ? "initial" : rows
    };
    useEffect(() => {
      if (contentRef.current) {
        const observer = new ResizeObserver(() => {
          if (!contentRef.current) return;
          setHeights({
            clientHeight: contentRef.current.clientHeight,
            scrollHeight: contentRef.current.scrollHeight
          });
        });
        observer.observe(contentRef.current);
        return () => {
          observer.disconnect();
        };
      }
    }, []);
    const inertOverflowFocusables = (entries) => {
      entries.forEach((element) => {
        if (!element.isIntersecting) {
          element.target.setAttribute("disabled", "true");
        } else {
          element.target.removeAttribute("disabled");
        }
      });
    };
    useEffect(() => {
      if (!("expandable" in props)) return;
      const observer = new IntersectionObserver(inertOverflowFocusables);
      const focusable = getKeyboardFocusableElements(contentRef.current);
      focusable.forEach((element) => {
        observer.observe(element);
      });
    }, [props.expandable]);
    const showExpand = expanded || heights.clientHeight < heights.scrollHeight;
    if ("expandable" in props && props.expandable === true) {
      const {
        expandable,
        expandText,
        collapseText,
        onExpand,
        onCollapse,
        ...expandableRest
      } = rest;
      const expandString = expandText ?? "Show more...";
      const collapseString = collapseText ?? "Show less...";
      const onExpandClickHandler = (e) => {
        setExpanded((prev) => !prev);
        if (expanded) {
          onCollapse?.(e);
          return;
        }
        onExpand?.(e);
      };
      const overflowTextClassNames2 = cx(
        [styles["overflow-text"]],
        [styles["expandable"]],
        className,
        {
          [styles["expanded"]]: expanded
        }
      );
      return /* @__PURE__ */ jsxs(
        "div",
        {
          ref,
          className: overflowTextClassNames2,
          style: styledCombined,
          "data-anv": "overflow-text",
          ...expandableRest,
          children: [
            /* @__PURE__ */ jsx("div", { className: styles["content"], ref: contentRef, children }),
            showExpand && /* @__PURE__ */ jsx(
              "button",
              {
                className: styles["expand-button"],
                onClick: onExpandClickHandler,
                children: expanded ? collapseString : expandString
              }
            )
          ]
        }
      );
    }
    const overflowTextClassNames = cx([styles["overflow-text"], className]);
    return /* @__PURE__ */ jsx(
      "div",
      {
        ref,
        className: overflowTextClassNames,
        style: styledCombined,
        "data-anv": "overflow-text",
        ...rest,
        children: /* @__PURE__ */ jsx("div", { className: styles["content"], children })
      }
    );
  }
);
OverflowText.displayName = "OverflowText";

const OverflowElement = forwardRef(
  (props, ref) => {
    const { layoutStyles, componentProps } = useLayoutPropsUtil(props);
    const {
      children,
      className,
      direction = "column",
      style,
      height,
      width,
      truncate,
      gap,
      ...rest
    } = componentProps;
    const contentRef = useRef(null);
    const [expanded, setExpanded] = useState(false);
    const [shadow, setShadow] = useState({
      left: false,
      right: false,
      top: false,
      bottom: false
    });
    const shadowUpdate = useCallback(() => {
      if (!contentRef.current) return;
      if (direction === "row") {
        const right = contentRef.current.offsetWidth < contentRef.current.scrollWidth;
        setShadow((prev) => {
          return {
            ...prev,
            right
          };
        });
        return;
      }
      const bottom = contentRef.current.offsetHeight < contentRef.current.scrollHeight;
      setShadow((prev) => {
        return {
          ...prev,
          bottom
        };
      });
    }, [direction]);
    useEffect(() => {
      if (contentRef.current) {
        const observer = new ResizeObserver(() => {
          shadowUpdate();
        });
        observer.observe(contentRef.current);
        return () => {
          observer.disconnect();
        };
      }
    }, [shadowUpdate]);
    useEffect(() => {
      shadowUpdate();
    }, [shadowUpdate]);
    const handleOnScroll = () => {
      if (!contentRef.current) return;
      const target = contentRef.current;
      if (direction === "row") {
        const left = target.scrollLeft > 0;
        const right = target.scrollLeft < target.scrollWidth - target.offsetWidth;
        setShadow({
          left,
          right,
          top: false,
          bottom: false
        });
        return;
      }
      const top = target.scrollTop > 0;
      const bottom = target.scrollTop < target.scrollHeight - target.offsetHeight;
      setShadow({
        top,
        bottom,
        left: false,
        right: false
      });
    };
    const inertOverflowFocusables = (entries) => {
      entries.forEach((element) => {
        if (!element.isIntersecting) {
          element.target.setAttribute("disabled", "true");
        } else {
          element.target.removeAttribute("disabled");
        }
      });
    };
    const overflowClassNames = cx([styles["overflow"]], className, {
      [styles["vertical"]]: direction === "column",
      [styles["horizontal"]]: direction === "row",
      [styles["truncate"]]: !!truncate,
      [styles["expanded"]]: expanded
    });
    useEffect(() => {
      if (!truncate) return;
      const observer = new IntersectionObserver(inertOverflowFocusables);
      const focusable = getKeyboardFocusableElements(contentRef.current);
      focusable.forEach((element) => {
        observer.observe(element);
      });
    }, [truncate]);
    if (truncate) {
      const wrapperStyle2 = {
        ...style,
        ...layoutStyles
      };
      const contentStyle2 = {
        minHeight: height ?? void 0,
        minWidth: width ?? void 0
      };
      const expandString = typeof truncate === "object" ? truncate.expandText : "Show more...";
      const collapseString = typeof truncate === "object" ? truncate.collapseText : "Show less...";
      const onExpandClickHandler = (e) => {
        setExpanded((prev) => !prev);
        setTimeout(() => {
          handleOnScroll();
        }, 100);
        if (typeof truncate !== "object") return;
        if (expanded) {
          truncate.onCollapse?.(e);
          return;
        }
        truncate.onExpand?.(e);
      };
      return /* @__PURE__ */ jsxs(
        "div",
        {
          ref,
          style: wrapperStyle2,
          className: overflowClassNames,
          "data-anv": "overflow",
          ...rest,
          children: [
            shadow.top && !truncate ? /* @__PURE__ */ jsx("div", { className: styles["shadow-top"] }) : null,
            shadow.left && !truncate ? /* @__PURE__ */ jsx("div", { className: styles["shadow-left"] }) : null,
            /* @__PURE__ */ jsx(
              Flex,
              {
                className: styles["content"],
                onScroll: handleOnScroll,
                style: contentStyle2,
                ref: contentRef,
                direction,
                gap,
                tabIndex: 0,
                children
              }
            ),
            shadow.bottom && !truncate ? /* @__PURE__ */ jsx("div", { className: styles["shadow-bottom"] }) : null,
            shadow.right && !truncate ? /* @__PURE__ */ jsx("div", { className: styles["shadow-right"] }) : null,
            truncate ? /* @__PURE__ */ jsx(
              "button",
              {
                className: styles["expand-button"],
                onClick: onExpandClickHandler,
                children: expanded ? collapseString : expandString
              }
            ) : null
          ]
        }
      );
    }
    const wrapperStyle = {
      ...style,
      ...layoutStyles
    };
    const contentStyle = {
      height: height ?? void 0,
      width: width ?? void 0
    };
    return /* @__PURE__ */ jsxs(
      "div",
      {
        ref,
        style: wrapperStyle,
        className: overflowClassNames,
        "data-anv": "overflow",
        ...rest,
        children: [
          shadow.left ? /* @__PURE__ */ jsx("div", { className: styles["shadow-left"] }) : null,
          shadow.top ? /* @__PURE__ */ jsx("div", { className: styles["shadow-top"] }) : null,
          /* @__PURE__ */ jsx(
            Flex,
            {
              className: styles["content"],
              onScroll: handleOnScroll,
              ref: contentRef,
              style: contentStyle,
              direction,
              gap,
              tabIndex: 0,
              children
            }
          ),
          shadow.bottom ? /* @__PURE__ */ jsx("div", { className: styles["shadow-bottom"] }) : null,
          shadow.right ? /* @__PURE__ */ jsx("div", { className: styles["shadow-right"] }) : null
        ]
      }
    );
  }
);
OverflowElement.displayName = "Overflow";
const Overflow = Object.assign(OverflowElement, {
  Text: OverflowText
});

export { OverflowText as O, Overflow as a };
//# sourceMappingURL=Overflow-ENfRRD_5-DLHLZ02e.js.map
