import { jsx, jsxs } from 'react/jsx-runtime';
import { forwardRef, useRef, useContext, createContext, useMemo, useState, useEffect, useLayoutEffect, useId, useCallback } from 'react';
import { i as DialogContext, o as DrawerContext, s as supportsPopover, j as useKeyboardFocusables, p as safeShowPopover, q as safeHidePopover } from './ProgressBar-CeClhdcf-Dcft7ZjO.js';
import { B as Button } from './Button-C-QpfgfF-CRBE7KiD.js';
import { F as FloatingPortal, a as FloatingFocusManager, b as FloatingArrow, c as useFloating, o as offset, s as size, f as flip, d as shift, e as arrow$1, l as limitShift, g as useClick, h as useHover, i as safePolygon, j as useDismiss, k as useRole, m as useInteractions, n as autoUpdate, p as computePosition } from './floating-ui.react-Domgunz0.js';
import { u as useMergeRefs } from './useMergeRefs-Bde85AWI-Bde85AWI.js';
import { c as cx } from './index-tZvMCc77.js';
import { a as PortalProviderContext } from './PortalProvider-9lXkQ0xY-BKoGegS1.js';
import { T as ThemeProvider, a as ThemeProviderContext } from './ThemeProvider-BIeaAmWx-DVYOQ6bw.js';

import './Popover-CpyYXmal.css';function usePopoverLegacy({
  defaultOpen,
  placement = "bottom",
  modal,
  open: controlledOpen,
  onOpenChange: setControlledOpen,
  onOutsidePress,
  onClose,
  disableCloseOnClickOutside,
  disableCloseOnEscape,
  openOnHover,
  fillAvailableHeight,
  fitScreen,
  maxHeight,
  minHeight = "2.875rem",
  matchReferenceWidth,
  fixedWidth,
  disableCaret,
  noPadding,
  disableShift,
  disableFlip,
  disableFlipFallback,
  disableAutoUpdate,
  disableFocusLock,
  disableTriggerFocus,
  root
} = {}) {
  const [uncontrolledOpen, setUncontrolledOpen] = useState(defaultOpen);
  const [labelId, setLabelId] = useState();
  const [descriptionId, setDescriptionId] = useState();
  const open = controlledOpen ?? uncontrolledOpen;
  const setOpen = setControlledOpen ?? setUncontrolledOpen;
  const arrowRef = useRef(null);
  const processMinHeight = typeof minHeight === "string" ? minHeight : `${minHeight}px`;
  const data = useFloating({
    placement,
    open,
    onOpenChange: setOpen,
    whileElementsMounted: !disableAutoUpdate ? autoUpdate : void 0,
    middleware: [
      offset(8),
      size({
        padding: 5,
        apply({ rects, availableHeight, elements }) {
          Object.assign(elements.floating.style, {
            ...matchReferenceWidth ? { width: `${rects.reference.width}px` } : fixedWidth ? { width: "40dvw" } : {},
            ...fillAvailableHeight ? {
              height: `${availableHeight - 20}px`,
              minHeight: processMinHeight
            } : {},
            ...maxHeight ? {
              minHeight: processMinHeight,
              height: fitScreen ? typeof maxHeight === "string" ? maxHeight : `${maxHeight}px` : void 0,
              maxHeight: fitScreen ? `${availableHeight - 20}px` : typeof maxHeight === "string" ? maxHeight : `${maxHeight}px`
            } : {},
            ...fitScreen && !maxHeight ? {
              minHeight: processMinHeight,
              maxHeight: `${availableHeight - 20}px`
            } : {},
            zIndex: 1
          });
        }
      }),
      flip({
        mainAxis: !disableFlip,
        crossAxis: false,
        fallbackAxisSideDirection: disableFlipFallback ? "none" : "end",
        padding: 5
      }),
      shift({
        padding: 5,
        mainAxis: !disableShift,
        crossAxis: false,
        limiter: limitShift({
          mainAxis: !disableShift
        })
      }),
      arrow$1({ element: !disableCaret ? arrowRef : null, padding: 5 })
    ]
  });
  const context = data.context;
  const click = useClick(context, {
    enabled: controlledOpen == null && !openOnHover
  });
  const hover = useHover(context, {
    enabled: controlledOpen == null && !!openOnHover,
    handleClose: safePolygon()
  });
  const dismiss = useDismiss(context, {
    escapeKey: !disableCloseOnEscape,
    outsidePress: (event) => {
      if (disableCloseOnClickOutside) {
        return false;
      }
      const result = typeof onOutsidePress === "function" ? onOutsidePress?.(event) : true;
      if (!result) {
        return result;
      } else {
        onClose?.();
        setOpen(false);
        return result;
      }
    }
  });
  const role = useRole(context);
  const interactions = useInteractions([click, hover, dismiss, role]);
  return useMemo(
    () => ({
      open,
      setOpen,
      onClose,
      ...interactions,
      ...data,
      modal,
      labelId,
      descriptionId,
      setLabelId,
      setDescriptionId,
      arrowRef,
      disableCaret,
      noPadding,
      fillAvailableHeight,
      maxHeight,
      matchReferenceWidth,
      fixedWidth,
      disableFlipFallback,
      disableAutoUpdate,
      disableFocusLock,
      disableTriggerFocus,
      root
    }),
    [
      open,
      setOpen,
      onClose,
      interactions,
      data,
      modal,
      labelId,
      descriptionId,
      disableCaret,
      noPadding,
      fillAvailableHeight,
      maxHeight,
      matchReferenceWidth,
      fixedWidth,
      disableFlipFallback,
      disableAutoUpdate,
      disableFocusLock,
      disableTriggerFocus,
      root
    ]
  );
}

const PopoverLegacyContext = createContext(null);
const usePopoverLegacyContext = () => {
  const context = useContext(PopoverLegacyContext);
  if (context == null) {
    throw new Error("Popover components must be wrapped in <Popover />");
  }
  return context;
};

const PopoverLegacyTrigger = function PopoverLegacyTrigger2(props) {
  const { children } = props;
  const context = usePopoverLegacyContext();
  const ref = useRef(null);
  const mergedRef = useMergeRefs([context.refs.setReference, ref]);
  return children({
    "data-state": context.open ? "open" : "closed",
    "data-anv": "popover-trigger",
    ...context.getReferenceProps({ ref: mergedRef })
  });
};

const styles$1 = {
	"content-legacy": "_content-legacy_vcgi9_3",
	"scroller-legacy": "_scroller-legacy_vcgi9_27",
	"arrow-legacy": "_arrow-legacy_vcgi9_34",
	"no-padding": "_no-padding_vcgi9_45"
};

const PopoverLegacyContent = forwardRef(function PopoverContent({ className, style, ...props }, propRef) {
  const {
    context: floatingContext,
    theme,
    mode,
    disableCaret,
    noPadding,
    onClose,
    disableFocusLock,
    disableTriggerFocus,
    root,
    ...context
  } = usePopoverLegacyContext();
  const dialogContext = useContext(DialogContext);
  const drawerContext = useContext(DrawerContext);
  const { root: portalRoot } = useContext(PortalProviderContext);
  const ref = useMergeRefs([context.refs.setFloating, propRef]);
  if (!floatingContext.open) return null;
  if (dialogContext && !dialogContext?.ref?.current) return null;
  const popoverClassNames = cx(className, styles$1["content-legacy"], {
    [styles$1["no-padding"]]: noPadding
  });
  const onKeyDownHandler = (e) => {
    if (e.code === "Escape") {
      onClose?.();
    }
  };
  return /* @__PURE__ */ jsx(
    FloatingPortal,
    {
      root: root ?? dialogContext?.ref?.current ?? drawerContext?.ref?.current ?? portalRoot,
      children: /* @__PURE__ */ jsx(
        FloatingFocusManager,
        {
          context: floatingContext,
          modal: context.modal,
          order: disableTriggerFocus ? ["content"] : ["reference", "content"],
          disabled: disableFocusLock,
          children: /* @__PURE__ */ jsx(ThemeProvider, { theme, mode, children: /* @__PURE__ */ jsxs(
            "div",
            {
              ref,
              "data-anv": "popover-content",
              style: { ...context.floatingStyles, ...style },
              "aria-labelledby": context.labelId,
              "aria-describedby": context.descriptionId,
              className: popoverClassNames,
              ...context.getFloatingProps(props),
              onKeyDown: onKeyDownHandler,
              role: "presentation",
              children: [
                /* @__PURE__ */ jsx("div", { className: styles$1["scroller-legacy"], children: props.children }),
                !disableCaret && /* @__PURE__ */ jsx(
                  FloatingArrow,
                  {
                    ref: context.arrowRef,
                    context: floatingContext,
                    className: styles$1["arrow-legacy"]
                  }
                )
              ]
            }
          ) })
        }
      )
    }
  );
});

const PopoverLegacyClose = forwardRef(function PopoverClose(props, ref) {
  const { setOpen, onClose } = usePopoverLegacyContext();
  return /* @__PURE__ */ jsx(
    Button,
    {
      ref,
      "data-anv": "popover-close",
      ...props,
      onClick: (event) => {
        props.onClick?.(event);
        onClose?.();
        setOpen(false);
      }
    }
  );
});

const PopoverLegacyButton = forwardRef(function PopoverButton(props, ref) {
  const { children, size, ...rest } = props;
  const context = usePopoverLegacyContext();
  const childrenRef = children?.ref;
  const mergedRef = useMergeRefs([context.refs.setReference, ref, childrenRef]);
  return /* @__PURE__ */ jsx(
    Button,
    {
      ref: mergedRef,
      size,
      "data-state": context.open ? "open" : "closed",
      "data-anv": "popover-button",
      ...context.getReferenceProps(rest),
      children
    }
  );
});

function PopoverLegacyElement({
  children,
  modal,
  ...restOptions
}) {
  const popover = usePopoverLegacy({ modal, ...restOptions });
  const { theme, mode = "light" } = useContext(ThemeProviderContext);
  const value = useMemo(
    () => ({ ...popover, theme, mode }),
    [mode, popover, theme]
  );
  return /* @__PURE__ */ jsx(PopoverLegacyContext.Provider, { value, children });
}
const PopoverLegacy = Object.assign(PopoverLegacyElement, {
  Trigger: PopoverLegacyTrigger,
  Close: PopoverLegacyClose,
  Content: PopoverLegacyContent,
  Button: PopoverLegacyButton
});

const useOnClickOutside = ({
  onOutsidePress,
  targets,
  onClose
}) => {
  useEffect(() => {
    if (typeof document === "undefined") return;
    let isClosable = false;
    const onMouseDownHandler = (e) => {
      let isTarget = false;
      const path = e.composedPath();
      for (const el of targets) {
        if (el && path.includes(el)) {
          isTarget = true;
          break;
        }
      }
      if (!isTarget) {
        onOutsidePress?.(e);
        isClosable = true;
      }
    };
    const onMouseUpHandler = (e) => {
      if (!isClosable) return;
      let isTarget = false;
      const path = e.composedPath();
      for (const el of targets) {
        if (el && path.includes(el)) {
          isTarget = true;
          break;
        }
      }
      if (!isTarget) {
        onClose?.();
      }
    };
    document.addEventListener("mousedown", onMouseDownHandler);
    document.addEventListener("mouseup", onMouseUpHandler);
    return () => {
      document.removeEventListener("mousedown", onMouseDownHandler);
      document.removeEventListener("mouseup", onMouseUpHandler);
    };
  }, [onClose, onOutsidePress, targets]);
};

function compareElements(el1, el2, excludeAttributes = []) {
  if (!el1 || !el2 || el1.tagName !== el2.tagName) {
    return false;
  }
  const getFilteredAttributes = (attrs) => {
    const filtered = {};
    for (let i = 0; i < attrs.length; i++) {
      const attr = attrs[i];
      if (!excludeAttributes.includes(attr.name)) {
        filtered[attr.name] = attr.value;
      }
    }
    return filtered;
  };
  const filteredAttrs1 = getFilteredAttributes(el1.attributes);
  const filteredAttrs2 = getFilteredAttributes(el2.attributes);
  const keys1 = Object.keys(filteredAttrs1);
  const keys2 = Object.keys(filteredAttrs2);
  if (keys1.length !== keys2.length) return false;
  for (const key of keys1) {
    if (filteredAttrs1[key] !== filteredAttrs2[key]) {
      return false;
    }
  }
  const isOnlyText1 = el1.childNodes.length === 1 && el1.childNodes[0].nodeType === Node.TEXT_NODE;
  const isOnlyText2 = el2.childNodes.length === 1 && el2.childNodes[0].nodeType === Node.TEXT_NODE;
  if (isOnlyText1 && isOnlyText2) {
    if (el1.textContent?.trim() !== el2.textContent?.trim()) {
      return false;
    }
  }
  const children1 = el1.children;
  const children2 = el2.children;
  if (children1.length !== children2.length) return false;
  for (let i = 0; i < children1.length; i++) {
    if (!compareElements(
      children1[i],
      children2[i],
      excludeAttributes
    )) {
      return false;
    }
  }
  return true;
}

const PopoverContext = createContext(null);

function usePopoverContext() {
  const context = useContext(PopoverContext);
  const invokerRef = useRef(null);
  const popoverRef = useRef(null);
  const arrowRef = useRef(null);
  useLayoutEffect(() => {
    if (!invokerRef.current) return;
    context?.setInvoker?.(invokerRef.current);
  }, [context, invokerRef]);
  useLayoutEffect(() => {
    if (!popoverRef.current) return;
    context?.setPopover?.(popoverRef.current);
    context?.setRootNode?.(popoverRef.current.getRootNode());
    if (!arrowRef.current) return;
    context?.setArrowElement?.(arrowRef.current);
  }, [context, popoverRef]);
  const onMouseEnterHandler = () => {
    if (!context?.openOnHover) return;
    context.openPopover();
  };
  const onMouseLeaveHandler = () => {
    if (!context?.openOnHover) return;
    context.closePopover();
  };
  const onFocusHandler = () => {
    if (context?.controlled || !context?.openOnHover) return;
    context?.openPopover();
  };
  const onBlurHandler = () => {
    if (context?.controlled || context?.disableCloseOnClickOutside || !context?.openOnHover)
      return;
    context?.closePopover();
  };
  const onKeyDownHandler = (e) => {
    if (!context?.openState) return;
    if (e.code === "Escape" && !context?.disableCloseOnEscape && !context?.controlled) {
      context?.closePopover();
      return;
    }
    const focusables = context.focusables;
    if (e.code === "Tab" && e.shiftKey && context?.modal && focusables) {
      focusables[focusables.length - 1].focus();
      e.preventDefault();
      return;
    }
  };
  const onClickHandler = () => {
    context?.invoker?.focus();
    if (context?.openOnHover) return;
    if (context?.controlled === false) {
      if (context?.openState) {
        context?.closePopover();
      } else {
        context?.openPopover();
      }
      return;
    }
  };
  if (!context || !invokerRef || !popoverRef) return;
  return {
    invoker: {
      ref: invokerRef,
      element: context.invoker,
      onMouseEnter: onMouseEnterHandler,
      onMouseLeave: onMouseLeaveHandler,
      onKeyDown: onKeyDownHandler,
      onClick: onClickHandler,
      onFocus: onFocusHandler,
      onBlur: onBlurHandler,
      "aria-haspopup": true,
      "aria-expanded": context.openState,
      "aria-details": context.popoverId,
      "data-state": context.openState ? "open" : "closed"
    },
    popover: {
      ref: popoverRef,
      element: context.popover,
      id: context.popoverId,
      onClose: context.onClose,
      show: context.openPopover,
      close: context.closePopover,
      noPadding: context.noPadding,
      style: context.popoverStyle,
      arrowRef,
      key: context.resetKey
    },
    rootNode: context.rootNode,
    onClose: context.onClose,
    setOpen: context.setOpenState,
    open: context.openState,
    openOnHover: context.openOnHover,
    controlled: context.controlled,
    disableCloseOnClickOutside: context.disableCloseOnClickOutside,
    disableCloseOnEscape: context.disableCloseOnEscape,
    modal: context.modal,
    placement: context.placement,
    disableCaret: context.disableCaret,
    noPadding: context.noPadding,
    fillAvailableHeight: context.fillAvailableHeight,
    maxHeight: context.maxHeight,
    matchReferenceWidth: context.matchReferenceWidth,
    fixedWidth: context.fixedWidth,
    disableFlipFallback: context.disableFlipFallback,
    disableFocusLock: context.modal,
    disableTriggerFocus: context.disableTriggerFocus,
    focusables: context.focusables
  };
}

const PopoverButton = forwardRef(
  function PopoverButton2(props, ref) {
    const {
      children,
      size,
      onMouseEnter,
      onMouseLeave,
      onClick,
      onKeyDown,
      onFocus,
      onBlur,
      ...rest
    } = props;
    const context = usePopoverContext();
    const onMouseEnterHandler = (e) => {
      onMouseEnter?.(e);
      context?.invoker.onMouseEnter();
    };
    const onMouseLeaveHandler = (e) => {
      onMouseLeave?.(e);
      context?.invoker.onMouseLeave();
    };
    const onFocusHandler = (e) => {
      onFocus?.(e);
      context?.invoker.onFocus();
    };
    const onBlurHandler = (e) => {
      onBlur?.(e);
      context?.invoker.onBlur();
    };
    const onKeyDownHandler = (e) => {
      onKeyDown?.(e);
      context?.invoker.onKeyDown(e);
    };
    const onClickHandler = (e) => {
      onClick?.(e);
      context?.invoker.onClick();
    };
    const buttonRef = useMergeRefs([context?.invoker.ref, ref]);
    if (!supportsPopover())
      return /* @__PURE__ */ jsx(
        PopoverLegacyButton,
        {
          ...props,
          ref
        }
      );
    return /* @__PURE__ */ jsx(
      Button,
      {
        ref: buttonRef,
        size,
        onClick: onClickHandler,
        onKeyDown: onKeyDownHandler,
        onMouseEnter: onMouseEnterHandler,
        onMouseLeave: onMouseLeaveHandler,
        onFocus: onFocusHandler,
        onBlur: onBlurHandler,
        "data-anv": "popover-button",
        "aria-haspopup": context?.invoker["aria-haspopup"],
        "aria-expanded": context?.invoker["aria-expanded"],
        "aria-details": context?.invoker["aria-details"],
        "data-state": context?.invoker["data-state"],
        ...rest,
        children
      }
    );
  }
);

const PopoverClose = forwardRef(
  function PopoverClose2(props, ref) {
    const { onClick, ...rest } = props;
    const context = usePopoverContext();
    if (!supportsPopover())
      return /* @__PURE__ */ jsx(PopoverLegacyClose, { ...props, ref });
    return /* @__PURE__ */ jsx(
      Button,
      {
        ref,
        "data-anv": "popover-close",
        ...rest,
        onClick: (event) => {
          onClick?.(event);
          if (!context?.controlled) {
            context?.popover.close();
          } else {
            setTimeout(() => {
              context?.onClose?.();
            }, 100);
          }
        }
      }
    );
  }
);

const content = "_content_yo27y_2";
const scroller = "_scroller_yo27y_29";
const arrow = "_arrow_yo27y_37";
const styles = {
	content: content,
	scroller: scroller,
	arrow: arrow,
	"no-padding": "_no-padding_yo27y_62"
};

const PopoverContent = forwardRef(
  function PopoverContent2(props, ref) {
    const {
      children,
      className,
      style,
      onMouseEnter,
      onMouseLeave,
      onKeyDown,
      onFocus,
      onBlur,
      onScroll,
      onScrollCapture,
      scrollerRef,
      ...rest
    } = props;
    const context = usePopoverContext();
    const popoverClassNames = cx(className, styles["content"], {
      [styles["no-padding"]]: context?.noPadding
    });
    const childrenRef = useRef(null);
    const combinedStyles = {
      ...style,
      ...context?.popover.style
    };
    const focusables = context?.focusables;
    const onMouseEnterHandler = (e) => {
      onMouseEnter?.(e);
      if (!context?.openOnHover) return;
      context.popover.show();
    };
    const onMouseLeaveHandler = (e) => {
      onMouseLeave?.(e);
      if (!context?.openOnHover) return;
      context.popover.close();
    };
    const onFocusHandler = (e) => {
      onFocus?.(e);
      context?.popover.show();
    };
    const onBlurHandler = (e) => {
      onBlur?.(e);
      if (context?.controlled || context?.disableCloseOnClickOutside) return;
      context?.popover.close();
    };
    const onKeyDownHandler = (e) => {
      onKeyDown?.(e);
      if (e.code === "Escape" && !context?.disableCloseOnEscape) {
        context?.popover.close();
      }
      if (!context?.modal) return;
      if (e.code === "Tab" && !e.shiftKey) {
        if (focusables && compareElements(
          context.rootNode?.activeElement,
          focusables[focusables.length - 1],
          ["tabindex"]
        )) {
          if (context.disableTriggerFocus) {
            focusables[0].focus();
          } else {
            context.invoker.element?.focus();
            context.popover.show();
          }
          e.preventDefault();
        }
      }
      if (e.code === "Tab" && e.shiftKey) {
        if (focusables && compareElements(
          context.rootNode.activeElement,
          focusables[0],
          ["tabindex"]
        )) {
          if (context.disableTriggerFocus) {
            focusables[focusables.length - 1].focus();
          } else {
            context.invoker.element?.focus();
            context.popover.show();
          }
          e.preventDefault();
        }
      }
    };
    const manualPopover = context?.controlled || context?.disableCloseOnClickOutside || context?.disableCloseOnEscape || context?.openOnHover;
    const popoverContentRef = useMergeRefs([context?.popover.ref, ref]);
    const popoverScrollerRef = useMergeRefs([childrenRef, scrollerRef]);
    if (!supportsPopover())
      return /* @__PURE__ */ jsx(
        PopoverLegacyContent,
        {
          ...props,
          ref
        }
      );
    return /* @__PURE__ */ jsxs(
      "div",
      {
        popover: manualPopover ? "manual" : "auto",
        id: context?.popover.id,
        "data-anv": "popover-content",
        className: popoverClassNames,
        ref: popoverContentRef,
        style: combinedStyles,
        onMouseEnter: onMouseEnterHandler,
        onMouseLeave: onMouseLeaveHandler,
        onBlur: onBlurHandler,
        onFocus: onFocusHandler,
        role: "region",
        ...rest,
        children: [
          /* @__PURE__ */ jsx(
            "div",
            {
              className: styles.scroller,
              role: "presentation",
              tabIndex: -1,
              ref: popoverScrollerRef,
              onKeyDown: onKeyDownHandler,
              onScroll,
              onScrollCapture,
              children
            },
            context?.popover.key
          ),
          !context?.disableCaret && /* @__PURE__ */ jsx("span", { className: styles["arrow"], ref: context?.popover.arrowRef, children: /* @__PURE__ */ jsxs("svg", { "aria-hidden": "true", width: "14", height: "14", viewBox: "0 0 14 14", children: [
            /* @__PURE__ */ jsx("path", { stroke: "none", d: "M0,0 H14 L7,7 Q7,7 7,7 Z" }),
            /* @__PURE__ */ jsx("clipPath", { id: ":r9:", children: /* @__PURE__ */ jsx("rect", { x: "0", y: "0", width: "14", height: "14" }) })
          ] }) })
        ]
      }
    );
  }
);

function PopoverTrigger(props) {
  const { children } = props;
  const context = usePopoverContext();
  if (!supportsPopover())
    return /* @__PURE__ */ jsx(PopoverLegacyTrigger, { ...props });
  if (!context) return;
  const { element, ...rest } = context.invoker;
  return children({ "data-test": "hello", ...rest });
}

const PopoverElement = (props) => {
  const {
    children,
    openOnHover = false,
    delay = 100,
    placement = "bottom",
    minHeight = "2.875rem",
    open,
    defaultOpen = false,
    disableShift,
    disableFlip,
    disableFlipFallback,
    matchReferenceWidth,
    id,
    disableCaret,
    fixedWidth,
    fillAvailableHeight,
    maxHeight,
    disableCloseOnClickOutside,
    disableCloseOnEscape,
    fitScreen,
    disableFocusLock,
    disableTriggerFocus,
    modal,
    noPadding,
    onOutsidePress,
    onClose,
    root
  } = props;
  const uid = useId();
  const [invoker, setInvoker] = useState(void 0);
  const [popover, setPopover] = useState(void 0);
  const [rootNode, setRootNode] = useState();
  const [arrowElement, setArrowElement] = useState(void 0);
  const [openState, setOpenState] = useState(
    open ?? defaultOpen
  );
  const arrowRef = useRef(null);
  const dialogContext = useContext(DialogContext);
  const processMinHeight = typeof minHeight === "string" ? minHeight : `${minHeight}px`;
  const updatePosition = useCallback(() => {
    if (!invoker || !popover) return;
    if (!openState) return;
    computePosition(invoker, popover, {
      placement,
      middleware: [
        offset(8),
        size({
          padding: 5,
          apply({ rects, availableHeight, elements }) {
            Object.assign(elements.floating.style, {
              ...matchReferenceWidth ? { width: `${rects.reference.width}px` } : fixedWidth ? { width: "40dvw" } : {},
              ...fillAvailableHeight ? {
                height: `${availableHeight - 20}px`,
                minHeight: processMinHeight
              } : {},
              ...maxHeight ? {
                minHeight: processMinHeight,
                height: fitScreen ? typeof maxHeight === "string" ? maxHeight : `${maxHeight}px` : void 0,
                maxHeight: fitScreen ? `${availableHeight - 20}px` : typeof maxHeight === "string" ? maxHeight : `${maxHeight}px`
              } : {},
              ...fitScreen && !maxHeight ? {
                minHeight: processMinHeight,
                maxHeight: `${availableHeight - 20}px`
              } : {},
              zIndex: 1
            });
          }
        }),
        flip({
          mainAxis: !disableFlip,
          crossAxis: false,
          fallbackAxisSideDirection: disableFlipFallback ? "none" : "end",
          padding: 5
        }),
        shift({
          padding: 5,
          mainAxis: !disableShift,
          crossAxis: false,
          limiter: limitShift({
            mainAxis: !disableShift
          })
        }),
        arrow$1({
          element: !disableCaret && arrowElement ? arrowElement : null,
          padding: 5
        })
      ]
    }).then(({ x, y, placement: placement2, middlewareData }) => {
      const side = placement2.split("-")[0];
      const staticSide = {
        top: "bottom",
        right: "left",
        bottom: "top",
        left: "right"
      }[side];
      const arrowDeg = () => {
        if (staticSide === "top") return 180;
        if (staticSide === "bottom") return 0;
        if (staticSide === "left") return 90;
        return 270;
      };
      Object.assign(popover.style, {
        left: `${x}px`,
        top: `${y}px`
      });
      if (middlewareData.arrow && arrowElement) {
        const { x: x2, y: y2 } = middlewareData.arrow;
        Object.assign(arrowElement.style, {
          left: x2 != null ? `${x2}px` : "",
          top: y2 != null ? `${y2}px` : "",
          right: "",
          bottom: "",
          [staticSide]: `${-arrowElement.offsetWidth + 2}px`,
          transform: `rotate(${arrowDeg()}deg)`
        });
      }
    });
  }, [
    arrowElement,
    disableCaret,
    disableFlip,
    disableFlipFallback,
    disableShift,
    fillAvailableHeight,
    fitScreen,
    fixedWidth,
    invoker,
    matchReferenceWidth,
    maxHeight,
    openState,
    placement,
    popover,
    processMinHeight
  ]);
  const resetKey = useRef(0);
  useLayoutEffect(() => {
    if (!popover || !invoker) return;
    if (!openState) {
      resetKey.current += 1;
      return;
    }
    let requestID = null;
    const cleanup = autoUpdate(invoker, popover, () => {
      requestID = requestAnimationFrame(updatePosition);
    });
    return () => {
      if (requestID) cancelAnimationFrame(requestID);
      cleanup();
    };
  }, [invoker, popover, updatePosition, openState]);
  popover?.getRootNode();
  const { focusables } = useKeyboardFocusables(popover, {
    observeChange: true
  });
  const popoverId = id ?? `popover-${uid.replace(/:/g, "")}`;
  const isControlled = typeof open !== "undefined";
  const openTimeoutRef = useRef(null);
  const closeTimeoutRef = useRef(null);
  const openPopover = useCallback(() => {
    clearTimeout(closeTimeoutRef.current);
    clearTimeout(openTimeoutRef.current);
    if (!popover || !rootNode?.querySelector(`#${popoverId}`))
      return;
    openTimeoutRef.current = setTimeout(() => {
      safeShowPopover(popover);
      setOpenState(true);
      dialogContext?.setHasOpenPopover?.(true);
    }, delay);
  }, [popover, rootNode, popoverId, delay, dialogContext]);
  const closePopover = useCallback(
    (fn) => {
      clearTimeout(openTimeoutRef.current);
      clearTimeout(closeTimeoutRef.current);
      if (!popover || !openState) return;
      closeTimeoutRef.current = setTimeout(() => {
        if (!openOnHover) onClose?.();
        setOpenState(false);
        fn?.();
        safeHidePopover(popover);
        dialogContext?.setHasOpenPopover?.(false);
      }, 100);
    },
    [popover, openState, openOnHover, onClose, dialogContext]
  );
  const initialRender = useRef(true);
  useEffect(() => {
    if (openState) openPopover();
    if (initialRender.current === true) {
      if (openState) openPopover();
      initialRender.current = false;
      return;
    }
  }, [openPopover, openState]);
  useEffect(() => {
    if (typeof open === "undefined") return;
    if (open) {
      openPopover();
    } else {
      closePopover();
    }
  }, [closePopover, open, openPopover]);
  useOnClickOutside({
    onOutsidePress,
    targets: [invoker, popover],
    onClose: () => {
      if (disableCloseOnClickOutside || openOnHover || isControlled || !openState)
        return;
      closePopover();
    }
  });
  const value = useMemo(() => {
    return {
      popoverId,
      invoker,
      setInvoker,
      popover,
      setPopover,
      arrowElement,
      setArrowElement,
      openPopover,
      closePopover,
      placement,
      onClose,
      openOnHover,
      openState,
      setOpenState,
      disableCloseOnClickOutside,
      fillAvailableHeight,
      maxHeight,
      matchReferenceWidth,
      fixedWidth,
      disableCaret,
      disableFlipFallback,
      disableFocusLock,
      disableTriggerFocus,
      disableCloseOnEscape,
      noPadding,
      controlled: isControlled,
      modal: modal ?? disableFocusLock,
      arrowRef,
      resetKey: resetKey.current,
      rootNode,
      setRootNode,
      focusables
    };
  }, [
    popoverId,
    invoker,
    popover,
    arrowElement,
    openPopover,
    closePopover,
    placement,
    onClose,
    openOnHover,
    openState,
    disableCloseOnClickOutside,
    fillAvailableHeight,
    maxHeight,
    matchReferenceWidth,
    fixedWidth,
    disableCaret,
    disableFlipFallback,
    disableFocusLock,
    disableTriggerFocus,
    disableCloseOnEscape,
    noPadding,
    isControlled,
    modal,
    rootNode,
    focusables
  ]);
  if (!supportsPopover())
    return /* @__PURE__ */ jsx(PopoverLegacyElement, { ...props });
  return /* @__PURE__ */ jsx(PopoverContext.Provider, { value, children });
};
const Popover = Object.assign(PopoverElement, {
  Trigger: PopoverTrigger,
  Close: PopoverClose,
  Content: PopoverContent,
  Button: PopoverButton,
  Context: PopoverContext
});

export { PopoverTrigger as P, PopoverContent as a, PopoverClose as b, PopoverButton as c, Popover as d, PopoverLegacy as e, usePopoverContext as f, usePopoverLegacyContext as u };
//# sourceMappingURL=Popover-CpyYXmal-I-E-B4u8.js.map
