import { jsxs, jsx, Fragment } from 'react/jsx-runtime';
import { C as Card } from './Card-BNT0qpxt-OPUNKZW6.js';
import { R as RadioGroup, a as Radio } from './Radio-BlMDLvPw-DUeywcYR.js';
import { c as cx } from './index-tZvMCc77.js';
import { C as CheckboxGroup, a as Checkbox } from './Checkbox-CRurfeRE-BR_NXfh6.js';
import { forwardRef, useState, useId, createContext, useContext } from 'react';

import './SelectCard-D26y01WZ.css';const styles = {
	"select-card": "_select-card_17kzl_1",
	"select-card--disabled": "_select-card--disabled_17kzl_22",
	"select-card--errored": "_select-card--errored_17kzl_26",
	"select-card--selected": "_select-card--selected_17kzl_29"
};

const SelectCardContext = createContext(null);
const SelectCardProvider = ({
  children,
  onChange,
  selectionMode
}) => {
  const [selection, setSelection] = useState(/* @__PURE__ */ new Set());
  const radioName = useId();
  const handleChange = (e, state) => {
    if (!state || !state.id) {
      onChange(e, state);
      return;
    }
    if (selectionMode === "single") {
      state.checked ? setSelection(/* @__PURE__ */ new Set([state.id])) : setSelection(/* @__PURE__ */ new Set());
    } else {
      if (state.checked) {
        setSelection(selection.add(state.id));
      } else {
        selection.delete(state.id);
        setSelection(selection);
      }
    }
    onChange(e, state);
  };
  const context = {
    selectionMode,
    onChange: handleChange,
    radioName,
    selection
  };
  return /* @__PURE__ */ jsx(SelectCardContext.Provider, { value: context, children });
};
const useSelectCardContext = () => useContext(SelectCardContext);

const SelectCardGroup = forwardRef((props, ref) => {
  const {
    ariaLabelledBy,
    children,
    legend,
    onChange,
    required = false,
    selectionMode,
    ...rest
  } = props;
  return /* @__PURE__ */ jsxs(SelectCardProvider, { onChange, selectionMode, children: [
    selectionMode === "multiple" && /* @__PURE__ */ jsx(
      CheckboxGroup,
      {
        "aria-labelledby": ariaLabelledBy,
        legend,
        required,
        ...rest,
        children
      }
    ),
    selectionMode === "single" && /* @__PURE__ */ jsx(
      RadioGroup,
      {
        "aria-labelledby": ariaLabelledBy,
        legend,
        required,
        ...rest,
        children
      }
    )
  ] });
});
SelectCardGroup.displayName = "SelectCardGroup";

const SelectCardElement = forwardRef(
  (props, ref) => {
    const {
      checkboxProps,
      children,
      checked,
      className,
      defaultChecked,
      disabled,
      errored,
      radioProps,
      onChange,
      id,
      ...rest
    } = props;
    const [contextFreeIsChecked, setContextFreeIsChecked] = useState(
      defaultChecked || false
    );
    const context = useSelectCardContext();
    const handleChange = (event) => {
      const newChecked = event ? event.target.checked : false;
      onChange(newChecked);
      context?.onChange(event, {
        id,
        checked: newChecked
      });
      if (checked === void 0) {
        setContextFreeIsChecked(newChecked);
      }
    };
    const isChecked = context ? context.selection.has(id) : checked !== void 0 ? checked : contextFreeIsChecked;
    return /* @__PURE__ */ jsxs(Fragment, { children: [
      (!context || context?.selectionMode === "multiple") && /* @__PURE__ */ jsx(
        Checkbox,
        {
          ...checkboxProps,
          onChange: handleChange,
          disabled,
          ref,
          label: /* @__PURE__ */ jsx(
            Card,
            {
              ...rest,
              className: cx(
                styles["select-card"],
                isChecked && !errored && styles["select-card--selected"],
                errored && styles["select-card--errored"],
                disabled && styles["select-card--disabled"],
                className ?? ""
              ),
              children
            }
          ),
          hideCheckbox: true
        }
      ),
      context?.selectionMode === "single" && /* @__PURE__ */ jsx(
        Radio,
        {
          ...radioProps,
          onChange: handleChange,
          disabled,
          ref,
          name: context.radioName,
          label: /* @__PURE__ */ jsx(
            Card,
            {
              ...rest,
              className: cx(
                styles["select-card"],
                isChecked && !errored && styles["select-card--selected"],
                errored && styles["select-card--errored"],
                disabled && styles["select-card--disabled"],
                className ?? ""
              ),
              children
            }
          ),
          hideRadio: true
        }
      )
    ] });
  }
);
SelectCardElement.displayName = "SelectCard";
const SelectCard = Object.assign(SelectCardElement, {
  Group: SelectCardGroup
});

export { SelectCardGroup as S, SelectCard as a };
//# sourceMappingURL=SelectCard-D26y01WZ-BWN9G09J.js.map
