import { jsxs, jsx } from 'react/jsx-runtime';
import { forwardRef, useRef, useState, useMemo, useId } from 'react';
import { c as cx } from './index-tZvMCc77.js';
import { L as Label, H as Helper } from './ProgressBar-CeClhdcf-Dcft7ZjO.js';
import { S as Spinner } from './Spinner-DliJVzdW-BQlZEj4V.js';
import { t as textfieldStyles } from './TextField.module-ChLlwuT--ChLlwuT-.js';
import { S as SrOnly } from './SrOnly-BsKDHetF-B93X65F1.js';
import { u as useOptionallyControlledState } from './useOptionallyControlledState-DAv5LXXh-DAv5LXXh.js';
import { u as useLayoutPropsUtil } from './useLayoutPropsUtil-GT5myWCm-Clw_nEze.js';
import { u as useMergeRefs } from './useMergeRefs-Bde85AWI-Bde85AWI.js';

const TextFieldElement = forwardRef(
  function TextField2(props, ref) {
    const { layoutStyles, componentProps } = useLayoutPropsUtil(props);
    const {
      className,
      error,
      errorAriaLive: errorAriaLiveProp = "assertive",
      defaultValue: defaultValueProp,
      value: valueProp,
      label,
      moreInfo,
      prefix,
      suffix,
      size,
      type = "text",
      required,
      onChange,
      onFocus,
      onBlur,
      id: idProp,
      description,
      hint,
      showCounter,
      maxLength,
      loading,
      disabled,
      labelProps,
      style,
      placeholder,
      ...rest
    } = componentProps;
    const inputRef = useRef(null);
    const [isTyping, setIsTyping] = useState(false);
    const [openInfo, setOpenInfo] = useState(false);
    const [errorAriaLive, setErrorAriaLive] = useState("off");
    const [value, setValue] = useOptionallyControlledState({
      controlledValue: valueProp,
      defaultValue: defaultValueProp
    });
    const length = useMemo(() => {
      if (typeof value === "string" || typeof value === "number") {
        return String(value).length;
      }
      return 0;
    }, [value]);
    const onChangeHandler = (e) => {
      setValue(e.target.value);
      onChange?.(e);
      if (!isTyping) {
        setIsTyping(true);
      }
    };
    const focusHandler = (e) => {
      onFocus?.(e);
      setOpenInfo(true);
      setErrorAriaLive(errorAriaLiveProp);
    };
    const blurHandler = (e) => {
      onBlur?.(e);
      setOpenInfo(false);
      setErrorAriaLive("off");
    };
    const labelUid = useId();
    const id = idProp ?? labelUid;
    const prefixUid = useId();
    const suffixUid = useId();
    const helperUid = useId();
    const placeholderUid = useId();
    const errorMessage = typeof error !== "boolean" ? error : void 0;
    const styleCombined = { ...style, ...layoutStyles };
    return /* @__PURE__ */ jsxs(
      "div",
      {
        className: cx(textfieldStyles["textfield"], className),
        "data-anv": "textfield",
        style: styleCombined,
        children: [
          label ? /* @__PURE__ */ jsx(
            Label,
            {
              moreInfo,
              openMoreInfo: openInfo,
              required,
              htmlFor: id,
              ...labelProps,
              children: label
            }
          ) : null,
          /* @__PURE__ */ jsxs(
            "div",
            {
              className: cx(textfieldStyles["input-wrapper"], {
                [textfieldStyles["small"]]: size === "small",
                [textfieldStyles["large"]]: size === "large"
              }),
              role: "presentation",
              onClick: () => inputRef.current?.focus(),
              children: [
                prefix ? /* @__PURE__ */ jsx(
                  "div",
                  {
                    "aria-hidden": true,
                    className: textfieldStyles["prefix"],
                    id: `prefix${prefixUid}`,
                    children: prefix
                  }
                ) : null,
                /* @__PURE__ */ jsx(
                  "input",
                  {
                    id,
                    className: cx(textfieldStyles["input"], {
                      [textfieldStyles["error"]]: error
                    }),
                    onChange: onChangeHandler,
                    onFocus: focusHandler,
                    onBlur: blurHandler,
                    ref: useMergeRefs([ref, inputRef]),
                    required,
                    maxLength,
                    placeholder,
                    type,
                    disabled,
                    value: value ?? "",
                    ...rest,
                    "aria-describedby": [placeholderUid, helperUid].join(" "),
                    "aria-invalid": error ? !!error : void 0
                  }
                ),
                loading ? /* @__PURE__ */ jsx("div", { className: textfieldStyles["loading-spinner-wrapper"], children: /* @__PURE__ */ jsx(Spinner, {}) }) : null,
                suffix ? /* @__PURE__ */ jsx(
                  "div",
                  {
                    className: textfieldStyles["suffix"],
                    "aria-hidden": true,
                    id: `suffix${suffixUid}`,
                    children: suffix
                  }
                ) : null
              ]
            }
          ),
          hint || showCounter || errorMessage || description ? /* @__PURE__ */ jsx(
            Helper,
            {
              id: helperUid,
              hint,
              maxLength,
              inputLength: length,
              isTyping,
              showCounter,
              errorMessage,
              errorAriaLive,
              description
            }
          ) : null,
          /* @__PURE__ */ jsx(SrOnly, { "aria-hidden": true, id: placeholderUid, children: placeholder })
        ]
      }
    );
  }
);
const TextField = Object.assign(TextFieldElement, {});

export { TextField as T };
//# sourceMappingURL=TextField-Bp1q4hMI-2jGZG2k2.js.map
