import { jsxs, jsx } from 'react/jsx-runtime';
import * as React from 'react';
import React__default, { useLayoutEffect, forwardRef, useRef, useState, useEffect, useId } from 'react';
import { useTrackingId } from './useTrackingId.js';
import { c as childrenToString } from './childrenToString-Bz9MqbHb-Bz9MqbHb.js';
import { c as cx } from './index-tZvMCc77.js';
import { L as Label, H as Helper } from './ProgressBar-CeClhdcf-Dcft7ZjO.js';
import { _ as _objectWithoutPropertiesLoose, a as _extends } from './extends-Bg2s_OKl.js';
import { S as SrOnly } from './SrOnly-BsKDHetF-B93X65F1.js';
import { u as useLayoutPropsUtil } from './useLayoutPropsUtil-GT5myWCm-Clw_nEze.js';
import { u as useMergeRefs } from './useMergeRefs-Bde85AWI-Bde85AWI.js';

import './Textarea.css';var index$1 = useLayoutEffect ;

var useLatest = function useLatest(value) {
  var ref = React__default.useRef(value);
  index$1(function () {
    ref.current = value;
  });
  return ref;
};

// basically Exclude<React.ClassAttributes<T>["ref"], string>

var updateRef = function updateRef(ref, value) {
  if (typeof ref === 'function') {
    ref(value);
    return;
  }
  ref.current = value;
};
var useComposedRef = function useComposedRef(libRef, userRef) {
  var prevUserRef = React__default.useRef();
  return React__default.useCallback(function (instance) {
    libRef.current = instance;
    if (prevUserRef.current) {
      updateRef(prevUserRef.current, null);
    }
    prevUserRef.current = userRef;
    if (!userRef) {
      return;
    }
    updateRef(userRef, instance);
  }, [userRef]);
};

var HIDDEN_TEXTAREA_STYLE = {
  'min-height': '0',
  'max-height': 'none',
  height: '0',
  visibility: 'hidden',
  overflow: 'hidden',
  position: 'absolute',
  'z-index': '-1000',
  top: '0',
  right: '0',
  display: 'block'
};
var forceHiddenStyles = function forceHiddenStyles(node) {
  Object.keys(HIDDEN_TEXTAREA_STYLE).forEach(function (key) {
    node.style.setProperty(key, HIDDEN_TEXTAREA_STYLE[key], 'important');
  });
};
var forceHiddenStyles$1 = forceHiddenStyles;

var hiddenTextarea = null;
var getHeight = function getHeight(node, sizingData) {
  var height = node.scrollHeight;
  if (sizingData.sizingStyle.boxSizing === 'border-box') {
    // border-box: add border, since height = content + padding + border
    return height + sizingData.borderSize;
  }

  // remove padding, since height = content
  return height - sizingData.paddingSize;
};
function calculateNodeHeight(sizingData, value, minRows, maxRows) {
  if (minRows === void 0) {
    minRows = 1;
  }
  if (maxRows === void 0) {
    maxRows = Infinity;
  }
  if (!hiddenTextarea) {
    hiddenTextarea = document.createElement('textarea');
    hiddenTextarea.setAttribute('tabindex', '-1');
    hiddenTextarea.setAttribute('aria-hidden', 'true');
    forceHiddenStyles$1(hiddenTextarea);
  }
  if (hiddenTextarea.parentNode === null) {
    document.body.appendChild(hiddenTextarea);
  }
  var paddingSize = sizingData.paddingSize,
    borderSize = sizingData.borderSize,
    sizingStyle = sizingData.sizingStyle;
  var boxSizing = sizingStyle.boxSizing;
  Object.keys(sizingStyle).forEach(function (_key) {
    var key = _key;
    hiddenTextarea.style[key] = sizingStyle[key];
  });
  forceHiddenStyles$1(hiddenTextarea);
  hiddenTextarea.value = value;
  var height = getHeight(hiddenTextarea, sizingData);
  // Double set and calc due to Firefox bug: https://bugzilla.mozilla.org/show_bug.cgi?id=1795904
  hiddenTextarea.value = value;
  height = getHeight(hiddenTextarea, sizingData);

  // measure height of a textarea with a single row
  hiddenTextarea.value = 'x';
  var rowHeight = hiddenTextarea.scrollHeight - paddingSize;
  var minHeight = rowHeight * minRows;
  if (boxSizing === 'border-box') {
    minHeight = minHeight + paddingSize + borderSize;
  }
  height = Math.max(minHeight, height);
  var maxHeight = rowHeight * maxRows;
  if (boxSizing === 'border-box') {
    maxHeight = maxHeight + paddingSize + borderSize;
  }
  height = Math.min(maxHeight, height);
  return [height, rowHeight];
}

var noop = function noop() {};
var pick = function pick(props, obj) {
  return props.reduce(function (acc, prop) {
    acc[prop] = obj[prop];
    return acc;
  }, {});
};

var SIZING_STYLE = ['borderBottomWidth', 'borderLeftWidth', 'borderRightWidth', 'borderTopWidth', 'boxSizing', 'fontFamily', 'fontSize', 'fontStyle', 'fontWeight', 'letterSpacing', 'lineHeight', 'paddingBottom', 'paddingLeft', 'paddingRight', 'paddingTop',
// non-standard
'tabSize', 'textIndent',
// non-standard
'textRendering', 'textTransform', 'width', 'wordBreak', 'wordSpacing', 'scrollbarGutter'];
var isIE = !!document.documentElement.currentStyle ;
var getSizingData = function getSizingData(node) {
  var style = window.getComputedStyle(node);
  if (style === null) {
    return null;
  }
  var sizingStyle = pick(SIZING_STYLE, style);
  var boxSizing = sizingStyle.boxSizing;

  // probably node is detached from DOM, can't read computed dimensions
  if (boxSizing === '') {
    return null;
  }

  // IE (Edge has already correct behaviour) returns content width as computed width
  // so we need to add manually padding and border widths
  if (isIE && boxSizing === 'border-box') {
    sizingStyle.width = parseFloat(sizingStyle.width) + parseFloat(sizingStyle.borderRightWidth) + parseFloat(sizingStyle.borderLeftWidth) + parseFloat(sizingStyle.paddingRight) + parseFloat(sizingStyle.paddingLeft) + 'px';
  }
  var paddingSize = parseFloat(sizingStyle.paddingBottom) + parseFloat(sizingStyle.paddingTop);
  var borderSize = parseFloat(sizingStyle.borderBottomWidth) + parseFloat(sizingStyle.borderTopWidth);
  return {
    sizingStyle: sizingStyle,
    paddingSize: paddingSize,
    borderSize: borderSize
  };
};
var getSizingData$1 = getSizingData;

function useListener(target, type, listener) {
  var latestListener = useLatest(listener);
  React.useLayoutEffect(function () {
    var handler = function handler(ev) {
      return latestListener.current(ev);
    };

    // might happen if document.fonts is not defined, for instance
    if (!target) {
      return;
    }
    target.addEventListener(type, handler);
    return function () {
      return target.removeEventListener(type, handler);
    };
  }, []);
}
var useWindowResizeListener = function useWindowResizeListener(listener) {
  useListener(window, 'resize', listener);
};
var useFontsLoadedListener = function useFontsLoadedListener(listener) {
  useListener(document.fonts, 'loadingdone', listener);
};

var _excluded = ["cacheMeasurements", "maxRows", "minRows", "onChange", "onHeightChange"];
var TextareaAutosize = function TextareaAutosize(_ref, userRef) {
  var cacheMeasurements = _ref.cacheMeasurements,
    maxRows = _ref.maxRows,
    minRows = _ref.minRows,
    _ref$onChange = _ref.onChange,
    onChange = _ref$onChange === void 0 ? noop : _ref$onChange,
    _ref$onHeightChange = _ref.onHeightChange,
    onHeightChange = _ref$onHeightChange === void 0 ? noop : _ref$onHeightChange,
    props = _objectWithoutPropertiesLoose(_ref, _excluded);
  var isControlled = props.value !== undefined;
  var libRef = React.useRef(null);
  var ref = useComposedRef(libRef, userRef);
  var heightRef = React.useRef(0);
  var measurementsCacheRef = React.useRef();
  var resizeTextarea = function resizeTextarea() {
    var node = libRef.current;
    var nodeSizingData = cacheMeasurements && measurementsCacheRef.current ? measurementsCacheRef.current : getSizingData$1(node);
    if (!nodeSizingData) {
      return;
    }
    measurementsCacheRef.current = nodeSizingData;
    var _calculateNodeHeight = calculateNodeHeight(nodeSizingData, node.value || node.placeholder || 'x', minRows, maxRows),
      height = _calculateNodeHeight[0],
      rowHeight = _calculateNodeHeight[1];
    if (heightRef.current !== height) {
      heightRef.current = height;
      node.style.setProperty('height', height + "px", 'important');
      onHeightChange(height, {
        rowHeight: rowHeight
      });
    }
  };
  var handleChange = function handleChange(event) {
    if (!isControlled) {
      resizeTextarea();
    }
    onChange(event);
  };
  {
    React.useLayoutEffect(resizeTextarea);
    useWindowResizeListener(resizeTextarea);
    useFontsLoadedListener(resizeTextarea);
    return /*#__PURE__*/React.createElement("textarea", _extends({}, props, {
      onChange: handleChange,
      ref: ref
    }));
  }
};
var index = /* #__PURE__ */React.forwardRef(TextareaAutosize);

const textarea = "_textarea_1p24a_2";
const error = "_error_1p24a_59";
const disabled = "_disabled_1p24a_66";
const readonly = "_readonly_1p24a_76";
const styles = {
	textarea: textarea,
	"has-cols": "_has-cols_1p24a_22",
	error: error,
	disabled: disabled,
	"disable-resize": "_disable-resize_1p24a_73",
	readonly: readonly
};

const Textarea$1 = forwardRef(
  (props, ref) => {
    const { layoutStyles, componentProps } = useLayoutPropsUtil(props);
    const {
      className,
      disableResize,
      error,
      // errorAriaLive: errorAriaLiveProp = "assertive",
      hint,
      description,
      label,
      moreInfo,
      onChange,
      required,
      showCounter,
      onFocus,
      onBlur,
      id: idProp,
      maxLength,
      autoHeight,
      labelProps,
      placeholder,
      style,
      ...rest
    } = componentProps;
    const textareaRef = useRef(null);
    const [length, setLength] = useState(0);
    const [isTyping, setIsTyping] = useState(false);
    const [openInfo, setOpenInfo] = useState(false);
    const [errorAriaLive, setErrorAriaLive] = useState("off");
    const [ssr, setSSR] = useState(true);
    useEffect(() => {
      setSSR(false);
    }, []);
    useEffect(() => {
      setLength(textareaRef.current?.defaultValue.length ?? 0);
    }, []);
    const onChangeHandler = (e) => {
      onChange?.(e, { value: e.target.value });
      if (length !== e.target.value.length) {
        setIsTyping(true);
      }
      setLength(e.target.value.length);
    };
    const focusHandler = (e) => {
      onFocus?.(e);
      setOpenInfo(true);
    };
    const blurHandler = (e) => {
      onBlur?.(e);
      setOpenInfo(false);
      setErrorAriaLive("off");
      setIsTyping(false);
    };
    const labelUid = useId();
    const id = idProp ?? labelUid;
    const helperUid = useId();
    const placeholderUid = useId();
    const errorMessage = typeof error !== "boolean" ? error : void 0;
    const textareaClassNames = cx([styles["textarea"]], className, {
      [styles["error"]]: error,
      [styles["disable-resize"]]: disableResize,
      [styles["disabled"]]: rest.disabled,
      [styles["readonly"]]: rest.readOnly,
      [styles["has-cols"]]: rest.cols != null
    });
    const styleCombined = { ...style, ...layoutStyles };
    const TextareaComponent = autoHeight && !ssr ? index : "textarea";
    return /* @__PURE__ */ jsxs(
      "div",
      {
        className: textareaClassNames,
        "data-anv": "textarea",
        style: styleCombined,
        children: [
          label ? /* @__PURE__ */ jsx(
            Label,
            {
              htmlFor: id,
              moreInfo,
              openMoreInfo: openInfo,
              required,
              ...labelProps,
              children: label
            }
          ) : null,
          /* @__PURE__ */ jsx(
            TextareaComponent,
            {
              rows: 3,
              onChange: onChangeHandler,
              onFocus: focusHandler,
              onBlur: blurHandler,
              ref: useMergeRefs([ref, textareaRef]),
              required,
              maxLength,
              id,
              placeholder,
              ...rest,
              "aria-describedby": [placeholderUid, helperUid].join(" "),
              "aria-invalid": error ? !!error : void 0
            }
          ),
          hint || showCounter || errorMessage || description ? /* @__PURE__ */ jsx(
            Helper,
            {
              id: helperUid,
              hint,
              maxLength,
              inputLength: length,
              isTyping,
              showCounter,
              errorMessage,
              errorAriaLive,
              description
            }
          ) : null,
          /* @__PURE__ */ jsx(SrOnly, { "aria-hidden": true, id: placeholderUid, children: placeholder })
        ]
      }
    );
  }
);
Textarea$1.displayName = "Textarea";

const Textarea = forwardRef(
  (props, ref) => {
    const data = {
      label: childrenToString(props.label),
      labelProps: props.labelProps,
      prefix: childrenToString(props.prefix),
      hint: childrenToString(props.hint),
      description: childrenToString(props.description)
    };
    const trackingId = useTrackingId({
      name: "Textarea",
      data,
      hasOverride: !!props["data-tracking-id"]
    });
    return /* @__PURE__ */ jsx(Textarea$1, { ref, "data-tracking-id": trackingId, ...props });
  }
);

export { Textarea as T };
//# sourceMappingURL=Textarea-CMELRfU8.js.map
