export type OptionsObject<P extends Record<string, unknown>> = {
    [K in keyof P]: P[K][];
};
/**
 * Generate a list of props for a component that can be used to create a stickersheet for Chromatic.
 * This will return an array of props that can be used to create a stickersheet for Chromatic, including
 * a label that can be used to identify the variation in the stickersheet.
 *
 * @param props - The component props used to generate variations for the stickersheet.
 * @param labelFormatter - A function to format the label for the prop.
 * @param propsFormatter - A function to format the props. Return `false` to exclude a variation.
 * @returns An array of props that can be used to create a stickersheet for Chromatic.
 */
export declare const generateChromaticStickersheetProps: <P extends Record<string, unknown>, T extends OptionsObject<P> = OptionsObject<P>>(props?: Partial<T>, labelFormatter?: (values: Record<keyof T, unknown>) => string, propsFormatter?: (values: Record<keyof T, unknown>) => Record<string, unknown> | false) => (P & {
    label: string;
})[];
