import { useState, useCallback } from 'react';

function useOptionallyControlledState({
  controlledValue,
  defaultValue,
  onChange
}) {
  const [internalValue, setInternalValue] = useState(
    defaultValue
  );
  const isControlled = controlledValue !== void 0;
  const value = isControlled ? controlledValue : internalValue;
  const setValue = useCallback(
    (newValue) => {
      if (!isControlled) {
        setInternalValue(newValue);
      }
      onChange?.(newValue);
    },
    [isControlled, onChange]
  );
  return [value, setValue];
}

export { useOptionallyControlledState as u };
//# sourceMappingURL=useOptionallyControlledState-DAv5LXXh-DAv5LXXh.js.map
